@@ -3,5 +3,5 @@ package org.broad.igv.event;
 /**
  * Created by jrobinso on 2/7/17.
  */
-public class GenomeResetEvent {
+public final class GenomeResetEvent implements IGVEvent {
 }
