@@ -3,5 +3,5 @@ package org.broad.igv.event;
 /**
  * Created by jrobinso on 6/24/17.
  */
-public class RefreshEvent {
+public final class RefreshEvent implements IGVEvent {
 }
