@@ -2,7 +2,7 @@ package org.broad.igv.feature.basepair;
 
 //~--- non-JDK imports --------------------------------------------------------
 
-import org.apache.log4j.Logger;
+import org.broad.igv.logging.*;
 import org.broad.igv.feature.basepair.BasePairTrack.*;
 import org.broad.igv.track.RenderContext;
 import org.broad.igv.ui.color.ColorUtilities;
@@ -14,7 +14,7 @@ import java.awt.geom.GeneralPath;
 
 public class BasePairRenderer {
 
-    private static Logger log = Logger.getLogger(BasePairRenderer.class);
+    private static Logger log = LogManager.getLogger(BasePairRenderer.class);
 
     public void draw(BasePairData data,
                      RenderContext context,
