@@ -25,6 +25,7 @@
 
 package org.broad.igv.feature.genome;
 
+import org.broad.igv.feature.Chromosome;
 import org.broad.igv.ui.panel.ReferenceFrame;
 
 import java.util.List;
@@ -37,19 +38,31 @@ import java.util.List;
  */
 public interface Sequence {
 
-    byte[] getSequence(String chr, int start, int end, boolean useCache);
+    /**
+     * Return the sequence for the given range.  If sequence named "seq" does not exist returns null.
+     * @param seq
+     * @param start
+     * @param end
+     * @return  The sequence in bytes, or null if no sequence exists
+     */
+    byte[] getSequence(String seq, int start, int end) ;
 
-    byte getBase(String chr, int position);
+    byte getBase(String seq, int position);
 
     List<String> getChromosomeNames();
 
-    int getChromosomeLength(String chrname);
+    /**
+     * Return the given sequence length.  If no sequence exists with name "seq" return -1.
+     *
+     * @param seq
+     * @return
+     */
+    int getChromosomeLength(String seq);
 
-    default boolean isLoaded(ReferenceFrame frame) {
-        return false;
+    List<Chromosome> getChromosomes();
+
+    default boolean hasChromosomes() {
+        return true;
     }
 
-    boolean isRemote();
-
-    default boolean isFasta() {return false;}
 }
