@@ -33,6 +33,8 @@ import htsjdk.samtools.SAMTag;
 import org.broad.igv.logging.*;
 import org.broad.igv.feature.Range;
 import org.broad.igv.feature.Strand;
+import org.broad.igv.track.Track;
+import org.broad.igv.ui.panel.ReferenceFrame;
 
 import java.util.*;
 
@@ -65,9 +67,11 @@ public class AlignmentPacker {
      */
     public PackedAlignments packAlignments(
             AlignmentInterval interval,
-            AlignmentTrack.RenderOptions renderOptions) {
+            AlignmentTrack.RenderOptions renderOptions,
+            ReferenceFrame referenceFrame,
+            Track.DisplayMode displayMode) {
 
-        LinkedHashMap<String, List<Row>> packedAlignments = new LinkedHashMap<String, List<Row>>();
+        LinkedHashMap<String, List<Row>> packedAlignments = new LinkedHashMap<>();
 
         List<Alignment> alList = interval.getAlignments();
 
@@ -78,7 +82,11 @@ public class AlignmentPacker {
 
         if (renderOptions.getGroupByOption() == AlignmentTrack.GroupOption.NONE) {
             List<Row> alignmentRows = new ArrayList<>(10000);
-            pack(alList, renderOptions, alignmentRows);
+            if (displayMode == Track.DisplayMode.FULL) {
+                packFull(alList, renderOptions, alignmentRows, referenceFrame);
+            } else {
+                packDense(alList, renderOptions, alignmentRows);
+            }
             packedAlignments.put("", alignmentRows);
         } else {
 
@@ -99,11 +107,11 @@ public class AlignmentPacker {
             Comparator<Object> groupComparator = getGroupComparator(renderOptions.getGroupByOption());
 
             // Certain group options sort descending by default, as indicated by the "reverse" property
-            if(renderOptions.getGroupByOption().reverse) {
+            if (renderOptions.getGroupByOption().reverse) {
                 groupComparator = groupComparator.reversed();
             }
 
-            if(renderOptions.isInvertGroupSorting()){
+            if (renderOptions.isInvertGroupSorting()) {
                 groupComparator = groupComparator.reversed();
             }
             keys.sort(groupComparator);
@@ -111,7 +119,12 @@ public class AlignmentPacker {
             for (Object key : keys) {
                 List<Row> alignmentRows = new ArrayList<>(10000);
                 List<Alignment> group = groupedAlignments.get(key);
-                pack(group, renderOptions, alignmentRows);
+
+                if (displayMode == Track.DisplayMode.FULL) {
+                    packFull(group, renderOptions, alignmentRows, referenceFrame);
+                } else {
+                    packDense(group, renderOptions, alignmentRows);
+                }
                 packedAlignments.put(key.toString(), alignmentRows);
             }
         }
@@ -122,7 +135,7 @@ public class AlignmentPacker {
     }
 
 
-    private void pack(List<Alignment> alList, AlignmentTrack.RenderOptions renderOptions, List<Row> alignmentRows) {
+    private void packDense(List<Alignment> alList, AlignmentTrack.RenderOptions renderOptions, List<Row> alignmentRows) {
 
         Map<String, PairedAlignment> pairs = null;
 
@@ -132,14 +145,12 @@ public class AlignmentPacker {
             pairs = new HashMap<>(1000);
         }
 
-
         // Allocate alignemnts to buckets for each range.
         // We use priority queues to keep the buckets sorted by alignment length.  However this  is probably a needless
         // complication,  any collection type would do.
 
         int totalCount = 0;
 
-
         if (alList == null || alList.size() == 0) return;
 
         Range curRange = getAlignmentListRange(alList);
@@ -255,6 +266,49 @@ public class AlignmentPacker {
 
     }
 
+    private void packFull(List<Alignment> alList, AlignmentTrack.RenderOptions renderOptions, List<Row> alignmentRows, ReferenceFrame referenceFrame) {
+
+        Map<String, PairedAlignment> pairs = null;
+
+        boolean isPairedAlignments = renderOptions.isViewPairs();
+
+        if (isPairedAlignments) {
+            pairs = new HashMap<>(1000);
+        }
+
+        Range genomicRange = referenceFrame.getCurrentRange();
+
+        for (Alignment al : alList) {
+
+            if (al.isMapped()) {
+                Alignment alignment = al;
+
+                // Pair alignments -- do not pair secondaryalignments
+                if (isPairedAlignments && isPairable(al)) {
+                    String readName = al.getReadName();
+                    PairedAlignment pair = pairs.get(readName);
+                    if (pair == null) {
+                        pair = new PairedAlignment(al);
+                        pairs.put(readName, pair);
+                        alignment = pair;
+                    } else {
+                        // Add second alignment to pair.
+                        pair.setSecondAlignment(al);
+                        pairs.remove(readName);
+                        continue;
+                    }
+                }
+
+                if (alignment.getEnd() > genomicRange.start && alignment.getStart() < genomicRange.end) {
+                    Row row = new Row();
+                    row.addAlignment(alignment);
+                    alignmentRows.add(row);
+                }
+            }
+        }
+    }
+
+
     private boolean isPairable(Alignment al) {
         return al.isPrimary() &&
                 al.isPaired() &&
@@ -384,69 +438,64 @@ public class AlignmentPacker {
         Range pos = renderOptions.getGroupByPos();
         String readNameParts[], movieName, zmw;
 
-        switch (groupBy) {
-            case HAPLOTYPE:
-                return al.getHaplotypeName();
-            case STRAND:
-                return al.isNegativeStrand() ? "-" : "+";
-            case SAMPLE:
-                return al.getSample();
-            case LIBRARY:
-                return al.getLibrary();
-            case READ_GROUP:
-                return al.getReadGroup();
-            case LINKED:
-                return (al instanceof LinkedAlignment) ? "Linked" : "";
-            case PHASE:
-                return al.getAttribute("HP");
-            case TAG:
+        return switch (groupBy) {
+            case CLUSTER -> al.getClusterName();
+            case STRAND -> al.isNegativeStrand() ? "-" : "+";
+            case SAMPLE -> al.getSample();
+            case LIBRARY -> al.getLibrary();
+            case READ_GROUP -> al.getReadGroup();
+            case LINKED -> (al instanceof LinkedAlignment) ? "Linked" : "";
+            case PHASE -> al.getAttribute("HP");
+            case TAG -> {
                 Object tagValue = tag == null ? null : al.getAttribute(tag);
                 if (tagValue == null) {
-                    return null;
+                    yield null;
                 } else if (tagValue instanceof Integer || tagValue instanceof Float || tagValue instanceof Double) {
-                    return tagValue;
+                    yield tagValue;
                 } else {
-                    return tagValue.toString();
+                    yield tagValue.toString();
                 }
-            case FIRST_OF_PAIR_STRAND:
+            }
+            case FIRST_OF_PAIR_STRAND -> {
                 Strand strand = al.getFirstOfPairStrand();
-                String strandString = strand == Strand.NONE ? null : strand.toString();
-                return strandString;
-            case READ_ORDER:
+                yield strand == Strand.NONE ? null : strand.toString();
+            }
+            case READ_ORDER -> {
                 if (al.isPaired() && al.isFirstOfPair()) {
-                    return "FIRST";
+                    yield "FIRST";
                 } else if (al.isPaired() && al.isSecondOfPair()) {
-                    return "SECOND";
+                    yield "SECOND";
                 } else {
-                    return "";
+                    yield "";
                 }
-            case PAIR_ORIENTATION:
+            }
+            case PAIR_ORIENTATION -> {
                 PEStats peStats = AlignmentRenderer.getPEStats(al, renderOptions);
                 AlignmentTrack.OrientationType type = AlignmentRenderer.getOrientationType(al, peStats);
                 if (type == null) {
-                    return AlignmentTrack.OrientationType.UNKNOWN.name();
+                    yield AlignmentTrack.OrientationType.UNKNOWN.name();
                 }
-                return type.name();
-            case MATE_CHROMOSOME:
+                yield type.name();
+            }
+            case MATE_CHROMOSOME -> {
                 ReadMate mate = al.getMate();
                 if (mate == null) {
-                    return null;
+                    yield null;
                 }
                 if (!mate.isMapped()) {
-                    return "UNMAPPED";
+                    yield "UNMAPPED";
                 } else {
-                    return mate.getChr();
+                    yield mate.getChr();
                 }
-            case CHIMERIC:
-                return al.getAttribute(SAMTag.SA.name()) != null ?  "CHIMERIC" : "";
-            case SUPPLEMENTARY:
-                return al.isSupplementary() ? "SUPPLEMENTARY" : "";
-            case REFERENCE_CONCORDANCE:
-                return !al.isProperPair() ||
-                        al.getCigarString().toUpperCase().contains("S") ||
-                        al.isSupplementary() ?
-                        "DISCORDANT": "";
-            case BASE_AT_POS:
+            }
+            case NONE -> null;
+            case CHIMERIC -> al.getAttribute(SAMTag.SA.name()) != null ? "CHIMERIC" : "";
+            case SUPPLEMENTARY -> al.isSupplementary() ? "SUPPLEMENTARY" : "";
+            case REFERENCE_CONCORDANCE -> !al.isProperPair() ||
+                    al.getCigarString().toUpperCase().contains("S") ||
+                    al.isSupplementary() ?
+                    "DISCORDANT" : "";
+            case BASE_AT_POS -> {
                 // Use a string prefix to enforce grouping rules:
                 //    1: alignments with a base at the position
                 //    2: alignments with a gap at the position
@@ -459,14 +508,15 @@ public class AlignmentPacker {
 
                     byte[] baseAtPos = new byte[]{al.getBase(pos.getStart())};
                     if (baseAtPos[0] == 0) { // gap at position
-                        return "2:";
+                        yield "2:";
                     } else { // base at position
-                        return "1:" + new String(baseAtPos);
+                        yield "1:" + new String(baseAtPos);
                     }
                 } else { // does not overlap position
-                    return "3:";
+                    yield "3:";
                 }
-            case INSERTION_AT_POS:
+            }
+            case INSERTION_AT_POS -> {
                 // Use a string prefix to enforce grouping rules:
                 //    1: alignments with a base at the position
                 //    2: alignments with a gap at the position
@@ -477,38 +527,39 @@ public class AlignmentPacker {
                         al.getAlignmentEnd() > pos.getStart()) {
                     int insertionBaseCount = 0;
                     AlignmentBlock leftInsertion = al.getInsertionAt(pos.getStart() + 1);
-                    if(leftInsertion != null) {
+                    if (leftInsertion != null) {
                         insertionBaseCount += leftInsertion.getLength();
                     }
                     AlignmentBlock rightInsertion = al.getInsertionAt(pos.getStart());
-                    if(rightInsertion != null) {
+                    if (rightInsertion != null) {
                         insertionBaseCount += rightInsertion.getLength();
                     }
-                    return insertionBaseCount;
+                    yield insertionBaseCount;
 
                 } else {
-                    return 0;
+                    yield 0;
                 }
-
-            case MOVIE: // group PacBio reads by movie
+            }
+            case MOVIE -> {
                 readNameParts = al.getReadName().split("/");
                 if (readNameParts.length < 3) {
-                    return "";
+                    yield "";
                 }
                 movieName = readNameParts[0];
-                return movieName;
-            case ZMW: // group PacBio reads by ZMW
+                yield movieName; // group PacBio reads by movie
+            }
+            case ZMW -> {
                 readNameParts = al.getReadName().split("/");
                 if (readNameParts.length < 3) {
-                    return "";
+                    yield "";
                 }
                 movieName = readNameParts[0];
                 zmw = readNameParts[1];
-                return movieName + "/" + zmw;
-            case MAPPING_QUALITY:
-                return al.getMappingQuality();
-        }
-        return null;
+                yield movieName + "/" + zmw; // group PacBio reads by ZMW
+            }
+            case MAPPING_QUALITY -> al.getMappingQuality();
+            case DUPLICATE -> al.isDuplicate() ? "duplicate" : "non-duplicate";
+        };
     }
 
     interface BucketCollection {
