@@ -35,7 +35,6 @@ import org.broad.igv.logging.Logger;
 import org.broad.igv.prefs.IGVPreferences;
 import org.broad.igv.prefs.PreferencesManager;
 import org.broad.igv.renderer.GraphicUtils;
-import org.broad.igv.renderer.SequenceRenderer;
 import org.broad.igv.sam.AlignmentTrack.ColorOption;
 import org.broad.igv.sam.BisulfiteBaseInfo.DisplayStatus;
 import org.broad.igv.sam.mods.BaseModificationRenderer;
@@ -55,6 +54,7 @@ import org.broad.igv.util.ChromosomeColors;
 
 import java.awt.*;
 import java.awt.geom.Rectangle2D;
+import java.awt.image.BufferedImage;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
@@ -118,6 +118,7 @@ public class AlignmentRenderer {
     private static Map<String, AlignmentTrack.OrientationType> f2f1OrientationTypes;
     private static Map<String, AlignmentTrack.OrientationType> rfOrientationTypes;
     private static Map<AlignmentTrack.OrientationType, Color> typeToColorMap;
+    private static final Map<Color, TexturePaint> duplicateTextures = new HashMap<>();
 
     public static final HSLColorTable tenXColorTable1 = new HSLColorTable(30);
     public static final HSLColorTable tenXColorTable2 = new HSLColorTable(270);
@@ -325,11 +326,11 @@ public class AlignmentRenderer {
             int lastPixelDrawn = -1;
 
             for (Alignment alignment : alignments) {
-                // Compute the start and dend of the alignment in pixels
+                // Compute the start and end of the alignment in pixels
                 double pixelStart = ((alignment.getStart() - origin) / locScale);
                 double pixelEnd = ((alignment.getEnd() - origin) / locScale);
 
-                // If any any part of the feature fits in the track rectangle draw  it
+                // If any part of the feature fits in the track rectangle draw  it
                 if (pixelEnd < rowRect.x || pixelStart > rowRect.getMaxX()) {
                     continue;
                 }
@@ -667,7 +668,7 @@ public class AlignmentRenderer {
                 }
 
                 // gap extensions
-                if ( flowIndelRendering.handlesAlignment(alignment) ) {
+                if ( flowIndelRendering.handlesAlignment(alignment) && flowIndelRendering.handlesGap(gap)) {
                     flowIndelRendering.renderDeletionGap(alignment, gap, y, h, gapPxStart, gapPxEnd - gapPxStart, context, renderOptions);
                 }
             }
@@ -757,7 +758,18 @@ public class AlignmentRenderer {
                     else if (block.getCigarOperator() == 'X') g = context.getGraphics2D("MISMATCH");
                 }
 
-                g.fill(blockShape);
+                if(renderOptions.getDuplicatesOption() == AlignmentTrack.DuplicatesOption.TEXTURE && alignment.isDuplicate()) {
+                    final Graphics2D tg = (Graphics2D) g.create();
+
+                    final TexturePaint tp = getDuplicateTexture(tg.getColor());
+                    // Add the texture paint to the graphics context.
+                    tg.setPaint(tp);
+                    tg.fill(blockShape);
+                    tg.dispose();
+                }  else {
+                    g.fill(blockShape);
+                }
+
                 if (outlineGraphics != null) {
                     outlineGraphics.draw(blockShape);
                 }
@@ -928,7 +940,7 @@ public class AlignmentRenderer {
                         int pxWing = (h > 10 ? 2 : (h > 5) ? 1 : 0);
                         Graphics2D ig = context.getGraphics();
                         ig.setColor(purple);
-                        if ( flowIndelRendering.handlesAlignment(alignment) ) {
+                        if ( flowIndelRendering.handlesAlignment(alignment) && flowIndelRendering.handlesBlock(aBlock) ) {
                             flowIndelRendering.renderSmallInsertion(alignment, aBlock, context, h, x, y, renderOptions);
                         } else {
                             ig.fillRect(x, y, 2, h);
@@ -944,6 +956,35 @@ public class AlignmentRenderer {
 
     }
 
+    /**
+     * get a texture to apply to duplicate reads, caches the created textures according to their color
+     * @param baseColor the color to render the read
+     * @return a texture matching the base color with shading
+     */
+    private TexturePaint getDuplicateTexture(Color baseColor) {
+        return duplicateTextures.computeIfAbsent(baseColor, color -> {
+            BufferedImage texture = new BufferedImage(5, 5, BufferedImage.TYPE_INT_RGB);
+            Graphics2D big = texture.createGraphics();
+            //Render into the BufferedImage graphics to create the texture
+            big.setColor(baseColor);
+            big.fillRect(0, 0, 5, 5);
+
+            final Color darker = baseColor.darker();
+            big.setColor(darker);
+            // hash pattern, probably better to save it as a bitmap somewhere
+            big.drawLine(0, 2, 0, 3);
+            big.drawLine(1, 3, 1, 4);
+            big.drawLine(2, 4, 2, 4);
+            big.drawLine(2, 0, 2, 0);
+            big.drawLine(3, 0, 3, 1);
+            big.drawLine(4, 1, 4, 2);
+            big.dispose();
+            // Create a texture paint from the buffered image
+            Rectangle r = new Rectangle(0, 0, 5, 5);
+            return new TexturePaint(texture, r);
+        });
+    }
+
     private static void drawClippedEnds(final Graphics2D g, final int[] xPoly, final int[] yPoly,
                                         final boolean drawLeftClip, final boolean drawRightClip,
                                         final SupplementaryAlignment.SupplementaryNeighbors sri) {
@@ -1065,7 +1106,7 @@ public class AlignmentRenderer {
         g.fillRect(pxLeft, pxTop, pxRight - pxLeft, pxH);
 
         if (isInsertion && pxH > 5) {
-            if ( flowIndelRendering.handlesAlignment(alignment) ) {
+            if ( flowIndelRendering.handlesAlignment(alignment) && flowIndelRendering.handlesBlock(insertionBlock) ) {
                 flowIndelRendering.renderSmallInsertionWings(alignment, insertionBlock, context, pxH, pxTop, pxRight, pxLeft, track.renderOptions);
             } else {
                 g.fillRect(pxLeft - pxWing, pxTop, pxRight - pxLeft + 2 * pxWing, 2);
@@ -1083,104 +1124,6 @@ public class AlignmentRenderer {
         }
     }
 
-    public void renderExpandedInsertion(InsertionMarker i,
-                                        List<Alignment> alignments,
-                                        RenderContext context,
-                                        Rectangle rect,
-                                        boolean leaveMargin) {
-        double origin = context.getOrigin();
-        double locScale = context.getScale();
-        if ((alignments != null) && (alignments.size() > 0)) {
-
-            Graphics2D g = context.getGraphics2D("INSERTIONS");
-            double dX = 1 / context.getScale();
-            int fontSize = (int) Math.min(dX, 12);
-            if (fontSize >= 8) {
-                Font f = FontManager.getFont(Font.BOLD, fontSize);
-                g.setFont(f);
-            }
-
-            for (Alignment alignment : alignments) {
-                if (alignment.getEnd() < i.position) continue;
-                if (alignment.getStart() > i.position) break;
-                AlignmentBlock insertion = alignment.getInsertionAt(i.position);
-                if (insertion != null) {
-
-                    // Compute the start and dend of the alignment in pixels
-                    double pixelStart = (insertion.getStart() - origin) / locScale;
-                    double pixelEnd = (insertion.getEnd() - origin) / locScale;
-                    int x = (int) pixelStart;
-
-                    // If any any part of the feature fits in the track rectangle draw  it
-                    if (pixelEnd < rect.x || pixelStart > rect.getMaxX()) {
-                        continue;
-                    }
-
-                    int bpWidth = insertion.getBasesLength();
-                    double pxWidthExact = ((double) bpWidth) / locScale;
-                    int h = (int) Math.max(1, rect.getHeight() - 2);
-                    int y = (int) (rect.getY() + (rect.getHeight() - h) / 2) - 1;
-
-                    if (!insertion.hasBases()) {
-                        g.setColor(purple);
-                        g.fillRect(x, y, (int) pxWidthExact, h);
-
-                    } else {
-                        drawExpandedInsertionBases(x, context, rect, insertion, leaveMargin);
-                    }
-                }
-            }
-        }
-    }
-
-
-    private void drawExpandedInsertionBases(int pixelPosition,
-                                            RenderContext context,
-                                            Rectangle rect,
-                                            AlignmentBlock block,
-                                            boolean leaveMargin) {
-        Graphics2D g = context.getGraphics2D("INSERTIONS");
-        ByteSubarray bases = block.getBases();
-        int padding = block.getPadding();
-
-        double locScale = context.getScale();
-        double origin = context.getOrigin();
-
-        // Compute bounds
-        int pY = (int) rect.getY();
-        int dY = (int) rect.getHeight();
-        int dX = (int) Math.max(1, (1.0 / locScale));
-
-        final int size = bases.length + padding;
-        for (int p = 0; p < size; p++) {
-
-            char c = p < padding ? '-' : (char) bases.getByte(p - padding);
-
-            Color color = SequenceRenderer.nucleotideColors.get(c);
-            if (color == null) {
-                color = Color.black;
-            }
-
-            // If there is room for text draw the character, otherwise
-            // just draw a rectangle to represent the
-            int pX = (int) (pixelPosition + (p / locScale));
-
-            // Don't draw out of clipping rect
-            if (pX > rect.getMaxX()) {
-                break;
-            } else if (pX + dX < rect.getX()) {
-                continue;
-            }
-            BaseRenderer.drawBase(g, color, c, pX, pY, dX, dY - (leaveMargin ? 2 : 0), false, null);
-        }
-
-        int leftX = pixelPosition + context.translateX;
-        int rightX = leftX + rect.width;
-        block.setPixelRange(leftX, rightX);
-
-    }
-
-
     private Color getAlignmentColor(Alignment alignment, AlignmentTrack track) {
 
         // Set color used to draw the feature.  Highlight features that intersect the
