@@ -27,11 +27,7 @@ package org.broad.igv.sam;
 
 
 import org.broad.igv.Globals;
-import org.broad.igv.event.AlignmentTrackEvent;
-import org.broad.igv.event.DataLoadedEvent;
-import org.broad.igv.event.IGVEvent;
-import org.broad.igv.event.IGVEventBus;
-import org.broad.igv.event.IGVEventObserver;
+import org.broad.igv.event.*;
 import org.broad.igv.feature.FeatureUtils;
 import org.broad.igv.feature.Range;
 import org.broad.igv.feature.genome.Genome;
@@ -139,6 +135,19 @@ public class AlignmentTrack extends AbstractTrack implements IGVEventObserver {
         }
     }
 
+    public enum DuplicatesOption {
+        FILTER("filter duplicates", true),
+        SHOW("show duplicates", false),
+        TEXTURE("texture duplicates", false);
+
+        public final String label;
+        public final boolean filtered;
+
+        DuplicatesOption(String label, Boolean filtered) {
+            this.label = label;
+            this.filtered = filtered;
+        }
+    }
 
     public enum ShadeAlignmentsOption {
         NONE("none"),
@@ -168,12 +177,13 @@ public class AlignmentTrack extends AbstractTrack implements IGVEventObserver {
         INSERTION_AT_POS("insertion at position", true),
         MOVIE("movie"),
         ZMW("ZMW"),
-        HAPLOTYPE("haplotype"),
+        CLUSTER("cluster"),
         READ_ORDER("read order"),
         LINKED("linked"),
         PHASE("phase"),
         REFERENCE_CONCORDANCE("reference concordance"),
-        MAPPING_QUALITY("mapping quality");
+        MAPPING_QUALITY("mapping quality"),
+        DUPLICATE("duplicate flag");
 
         public final String label;
         public final boolean reverse;
@@ -361,11 +371,12 @@ public class AlignmentTrack extends AbstractTrack implements IGVEventObserver {
         }
         readNamePalette = new PaletteColorTable(ColorUtilities.getDefaultPalette());
 
-        dataManager.setViewAsPairs(prefs.getAsBoolean(SAM_DISPLAY_PAIRED), renderOptions);
+        dataManager.setViewAsPairs(prefs.getAsBoolean(SAM_DISPLAY_PAIRED), renderOptions, getDisplayMode());
 
         IGVEventBus.getInstance().subscribe(FrameManager.ChangeEvent.class, this);
         IGVEventBus.getInstance().subscribe(AlignmentTrackEvent.class, this);
         IGVEventBus.getInstance().subscribe(DataLoadedEvent.class, this);
+        IGVEventBus.getInstance().subscribe(ViewChange.class, this);
     }
 
     public void init() {
@@ -375,6 +386,10 @@ public class AlignmentTrack extends AbstractTrack implements IGVEventObserver {
         }
     }
 
+    @Override
+    public boolean isAlignment() {
+        return true;
+    }
 
     @Override
     public void receiveEvent(IGVEvent event) {
@@ -398,6 +413,10 @@ public class AlignmentTrack extends AbstractTrack implements IGVEventObserver {
                     return null; //remove this action from the map
                 });
             }
+        } else if (event instanceof ViewChange viewChange) {
+            if(viewChange.type == ViewChange.Type.LocusChange && !viewChange.panning && getDisplayMode() == DisplayMode.FULL) {
+                packAlignments();
+            }
         }
     }
 
@@ -468,6 +487,15 @@ public class AlignmentTrack extends AbstractTrack implements IGVEventObserver {
         return new AlignmentTrackMenu(this, te);
     }
 
+    @Override
+    public void setDisplayMode(DisplayMode mode) {
+        boolean repack = (getDisplayMode() == DisplayMode.FULL ||  mode == DisplayMode.FULL);
+        super.setDisplayMode(mode);
+        if(repack) {
+            packAlignments();
+        }
+    }
+
     @Override
     public void setHeight(int preferredHeight) {
         super.setHeight(preferredHeight);
@@ -484,9 +512,10 @@ public class AlignmentTrack extends AbstractTrack implements IGVEventObserver {
     }
 
     private int getRowHeight() {
-        if (getDisplayMode() == DisplayMode.EXPANDED) {
+        final DisplayMode displayMode = getDisplayMode();
+        if (displayMode == DisplayMode.EXPANDED || displayMode == DisplayMode.FULL) {
             return expandedHeight;
-        } else if (getDisplayMode() == DisplayMode.COLLAPSED) {
+        } else if (displayMode == DisplayMode.COLLAPSED) {
             return collapsedHeight;
         } else {
             return squishedHeight;
@@ -514,7 +543,7 @@ public class AlignmentTrack extends AbstractTrack implements IGVEventObserver {
         if (log.isDebugEnabled()) {
             log.debug("Reading - thread: " + Thread.currentThread().getName());
         }
-        dataManager.load(referenceFrame, renderOptions, true);
+        dataManager.load(referenceFrame, renderOptions, getDisplayMode(), true);
     }
 
     @Override
@@ -528,7 +557,11 @@ public class AlignmentTrack extends AbstractTrack implements IGVEventObserver {
         if (viewWindowSize > getVisibilityWindow()) {
             Rectangle visibleRect = context.getVisibleRect().intersection(rect);
             Graphics2D g2 = context.getGraphic2DForColor(Color.gray);
-            GraphicUtils.drawCenteredText("Zoom in to see alignments.", visibleRect, g2);
+            String message = context.getReferenceFrame().getChrName().equals(Globals.CHR_ALL) ?
+                    "Select a chromosome and zoom in to see alignments." :
+                    "Zoom in to see alignments.";
+
+            GraphicUtils.drawCenteredText(message, visibleRect, g2);
             return;
         }
 
@@ -615,9 +648,10 @@ public class AlignmentTrack extends AbstractTrack implements IGVEventObserver {
         // Divide rectangle into equal height levels
         double y = inputRect.getY();
         double h;
-        if (getDisplayMode() == DisplayMode.EXPANDED) {
+        final DisplayMode displayMode = getDisplayMode();
+        if (displayMode == DisplayMode.EXPANDED || displayMode == DisplayMode.FULL) {
             h = expandedHeight;
-        } else if (getDisplayMode() == DisplayMode.COLLAPSED) {
+        } else if (displayMode == DisplayMode.COLLAPSED) {
             h = collapsedHeight;
         } else {
 
@@ -796,7 +830,7 @@ public class AlignmentTrack extends AbstractTrack implements IGVEventObserver {
             renderOptions.setGroupByPos(pos);
         }
         renderOptions.setGroupByOption(option);
-        dataManager.packAlignments(renderOptions);
+        dataManager.packAlignments(renderOptions, getDisplayMode());
         repaint();
     }
 
@@ -819,7 +853,7 @@ public class AlignmentTrack extends AbstractTrack implements IGVEventObserver {
     }
 
     public void packAlignments() {
-        dataManager.packAlignments(renderOptions);
+        dataManager.packAlignments(renderOptions, getDisplayMode());
     }
 
 
@@ -937,7 +971,7 @@ public class AlignmentTrack extends AbstractTrack implements IGVEventObserver {
             }
         }
 
-        dataManager.setViewAsPairs(vAP, renderOptions);
+        dataManager.setViewAsPairs(vAP, renderOptions, getDisplayMode());
         repaint();
     }
 
@@ -1022,7 +1056,7 @@ public class AlignmentTrack extends AbstractTrack implements IGVEventObserver {
             showGroupLine = false;
             setDisplayMode(DisplayMode.SQUISHED);
         }
-        dataManager.packAlignments(renderOptions);
+        dataManager.packAlignments(renderOptions, getDisplayMode());
         repaint();
     }
 
@@ -1201,6 +1235,7 @@ public class AlignmentTrack extends AbstractTrack implements IGVEventObserver {
         private SortOption sortOption;
         private GroupOption groupByOption;
         private ShadeAlignmentsOption shadeAlignmentsOption;
+        private DuplicatesOption duplicatesOption;
         private Integer mappingQualityLow;
         private Integer mappingQualityHigh;
         private boolean viewPairs = false;
@@ -1211,6 +1246,8 @@ public class AlignmentTrack extends AbstractTrack implements IGVEventObserver {
         private Boolean linkedReads;
         private Boolean quickConsensusMode;
         private Boolean showMismatches;
+        private Boolean indelQualColoring;
+        private Boolean indelQualUsesMin;
         private Boolean insertQualColoring;
         Boolean computeIsizes;
         private Double minInsertSizePercentile;
@@ -1279,8 +1316,12 @@ public class AlignmentTrack extends AbstractTrack implements IGVEventObserver {
             this.viewPairs = viewPairs;
         }
 
-        void setInsertQualColoring(boolean insertQualColoring) {
-            this.insertQualColoring = insertQualColoring;
+        void setIndelQualColoring(boolean indelQualColoring) {
+            this.indelQualColoring = indelQualColoring;
+        }
+
+        void setIndelQualUsesMin(boolean indelQualUsesMin) {
+            this.indelQualUsesMin = indelQualUsesMin;
         }
 
         void setComputeIsizes(boolean computeIsizes) {
@@ -1401,6 +1442,13 @@ public class AlignmentTrack extends AbstractTrack implements IGVEventObserver {
             return viewPairs;
         }
 
+        public boolean isIndelQualColoring() {
+            return indelQualColoring == null ? getPreferences().getAsBoolean(SAM_INDEL_QUAL_COLORING) : indelQualColoring;
+        }
+        public boolean isIndelQualUsesMin() {
+            return indelQualUsesMin == null ? getPreferences().getAsBoolean(SAM_INDEL_QUAL_USES_MIN) : indelQualUsesMin;
+        }
+
         public boolean isInsertQualColoring() {
             return insertQualColoring == null ? getPreferences().getAsBoolean(SAM_INSERT_QUAL_COLORING) : insertQualColoring;
         }
@@ -1439,6 +1487,22 @@ public class AlignmentTrack extends AbstractTrack implements IGVEventObserver {
             }
         }
 
+        public DuplicatesOption getDuplicatesOption() {
+            final IGVPreferences prefs = getPreferences();
+            if (duplicatesOption != null) {
+                return duplicatesOption;
+            } else {
+                duplicatesOption = prefs.getAsBoolean(SAM_FILTER_DUPLICATES)
+                        ? DuplicatesOption.FILTER
+                        : DuplicatesOption.SHOW;
+            }
+            return duplicatesOption;
+        }
+
+        public void setDuplicatesOption(final DuplicatesOption duplicatesOption) {
+            this.duplicatesOption = duplicatesOption;
+        }
+
         public int getMappingQualityLow() {
             return mappingQualityLow == null ? getPreferences().getAsInt(SAM_SHADE_QUALITY_LOW) : mappingQualityLow;
         }
@@ -1562,6 +1626,9 @@ public class AlignmentTrack extends AbstractTrack implements IGVEventObserver {
             if (shadeAlignmentsOption != null) {
                 element.setAttribute("shadeAlignmentsByOption", shadeAlignmentsOption.toString());
             }
+            if (duplicatesOption != null) {
+                element.setAttribute("duplicatesOption", duplicatesOption.toString());
+            }
             if (mappingQualityLow != null) {
                 element.setAttribute("mappingQualityLow", mappingQualityLow.toString());
             }
@@ -1682,11 +1749,18 @@ public class AlignmentTrack extends AbstractTrack implements IGVEventObserver {
                 sortOption = SortOption.valueOf((element.getAttribute("sortOption")));
             }
             if (element.hasAttribute("groupByOption")) {
-                groupByOption = GroupOption.valueOf(element.getAttribute("groupByOption"));
+                String value = element.getAttribute("groupByOption");
+                if(value.equals("HAPLOTYPE")) {
+                    value = "CLUSTER";  // Backward compatibility
+                }
+                groupByOption = GroupOption.valueOf(value);
             }
             if (element.hasAttribute("shadeAlignmentsByOption")) {
                 shadeAlignmentsOption = ShadeAlignmentsOption.valueOf(element.getAttribute("shadeAlignmentsByOption"));
             }
+            if (element.hasAttribute("duplicatesOption")) {
+                duplicatesOption = CollUtils.valueOf(DuplicatesOption.class, element.getAttribute("duplicatesOption"), null);
+            }
             if (element.hasAttribute("mappingQualityLow")) {
                 mappingQualityLow = Integer.parseInt(element.getAttribute("mappingQualityLow"));
             }
@@ -1761,6 +1835,7 @@ public class AlignmentTrack extends AbstractTrack implements IGVEventObserver {
                 minJunctionCoverage = Integer.parseInt(element.getAttribute("minJunctionCoverage"));
             }
         }
+
     }
 
 
