@@ -2,7 +2,8 @@ package org.broad.igv.sam;
 
 import htsjdk.samtools.SAMTag;
 import org.broad.igv.Globals;
-import org.broad.igv.feature.Locus;
+import org.broad.igv.event.AlignmentTrackEvent;
+import org.broad.igv.event.IGVEventBus;
 import org.broad.igv.feature.Range;
 import org.broad.igv.feature.Strand;
 import org.broad.igv.jbrowse.CircularViewUtilities;
@@ -95,10 +96,6 @@ class AlignmentTrackMenu extends IGVPopupMenu {
         // Experiment type  (RNA, THIRD GEN, OTHER)
         addSeparator();
         addExperimentTypeMenuItem();
-//        if (alignmentTrack.getExperimentType() == AlignmentTrack.ExperimentType.THIRD_GEN) {
-//            addHaplotype(e);
-//        }
-
 
         // Group, sort, color, shade, and pack
         addSeparator();
@@ -117,6 +114,8 @@ class AlignmentTrackMenu extends IGVPopupMenu {
         misMatchesItem.addActionListener(new Deselector(misMatchesItem, showAllItem));
         showAllItem.addActionListener(new Deselector(showAllItem, misMatchesItem));
 
+        // Duplicates
+        addDuplicatesMenuItem();
 
         // Hide small indels
         JMenuItem smallIndelsItem = new JCheckBoxMenuItem("Hide small indels");
@@ -186,11 +185,42 @@ class AlignmentTrackMenu extends IGVPopupMenu {
             add(sashimi);
         }
 
+        // Experimental items
+        if (alignmentTrack.getExperimentType() == AlignmentTrack.ExperimentType.THIRD_GEN) {
+            addSeparator();
+            addClusterItem(e);
+        }
+
         // Show alignments, coverage, splice junctions
         addSeparator();
         addShowItems();
     }
 
+    private void addDuplicatesMenuItem() {
+        JMenu duplicatesMenu = new JMenu("Duplicates");
+        for (AlignmentTrack.DuplicatesOption option : AlignmentTrack.DuplicatesOption.values()) {
+            JRadioButtonMenuItem mi = new JRadioButtonMenuItem(option.label);
+            final AlignmentTrack.DuplicatesOption previous = renderOptions.getDuplicatesOption();
+            mi.setSelected(previous == option);
+            mi.addActionListener(aEvt -> {
+                renderOptions.setDuplicatesOption(option);
+                if(previous != option) {
+                    if (previous.filtered != option.filtered){
+                        // duplicates are filtered out when loading the read data so a reload has to be performed in this case
+                        IGVEventBus.getInstance().post(new AlignmentTrackEvent(AlignmentTrackEvent.Type.RELOAD));
+                    } else {
+                        alignmentTrack.repaint();
+                    }
+                } else {
+                    alignmentTrack.repaint();
+                }
+            });
+
+            duplicatesMenu.add(mi);
+        }
+        add(duplicatesMenu);
+    }
+
     private void addShowChimericRegions(final AlignmentTrack alignmentTrack, final TrackClickEvent e, final Alignment clickedAlignment) {
 
         JMenuItem item = new JMenuItem("View chimeric alignments in split screen");
@@ -233,9 +263,9 @@ class AlignmentTrackMenu extends IGVPopupMenu {
     }
 
 
-    private void addHaplotype(TrackClickEvent e) {
+    private void addClusterItem(TrackClickEvent e) {
 
-        JMenuItem item = new JMenuItem("Cluster (phase) alignments");
+        JMenuItem item = new JMenuItem("Cluster alignments  *EXPERIMENTAL*");
 
         final ReferenceFrame frame;
         if (e.getFrame() == null && FrameManager.getFrames().size() == 1) {
@@ -269,17 +299,14 @@ class AlignmentTrackMenu extends IGVPopupMenu {
             final int end = (int) frame.getEnd();
 
             AlignmentInterval interval = dataManager.getLoadedInterval(frame);
-            HaplotypeUtils haplotypeUtils = new HaplotypeUtils(interval);
-            boolean success = haplotypeUtils.clusterAlignments(frame.getChrName(), start, end, nClusters);
+            ClusterUtils clusterUtils = new ClusterUtils(interval);
+            boolean success = clusterUtils.clusterAlignments(frame.getChrName(), start, end, nClusters);
 
             if (success) {
-                groupAlignments(AlignmentTrack.GroupOption.HAPLOTYPE, null, null);
+                groupAlignments(AlignmentTrack.GroupOption.CLUSTER, null, null);
                 alignmentTrack.repaint();
             }
 
-            //dataManager.sortRows(SortOption.HAPLOTYPE, frame, (end + start) / 2, null);
-            //AlignmentTrack.repaint();
-
         });
 
 
@@ -423,15 +450,14 @@ class AlignmentTrackMenu extends IGVPopupMenu {
                 AlignmentTrack.GroupOption.SUPPLEMENTARY, AlignmentTrack.GroupOption.REFERENCE_CONCORDANCE,
                 AlignmentTrack.GroupOption.MOVIE, AlignmentTrack.GroupOption.ZMW, AlignmentTrack.GroupOption.READ_ORDER,
                 AlignmentTrack.GroupOption.LINKED, AlignmentTrack.GroupOption.PHASE,
-                AlignmentTrack.GroupOption.MAPPING_QUALITY
+                AlignmentTrack.GroupOption.MAPPING_QUALITY,
+                AlignmentTrack.GroupOption.DUPLICATE
         };
 
         for (final AlignmentTrack.GroupOption option : groupOptions) {
             JCheckBoxMenuItem mi = new JCheckBoxMenuItem(option.label);
             mi.setSelected(renderOptions.getGroupByOption() == option);
-            mi.addActionListener(aEvt -> {
-                groupAlignments(option, null, null);
-            });
+            mi.addActionListener(aEvt -> groupAlignments(option, null, null));
             groupMenu.add(mi);
             group.add(mi);
         }
@@ -487,7 +513,7 @@ class AlignmentTrackMenu extends IGVPopupMenu {
         invertGroupNameSortingOption.setSelected(renderOptions.isInvertGroupSorting());
         invertGroupNameSortingOption.addActionListener(aEvt -> {
             renderOptions.setInvertGroupSorting(!renderOptions.isInvertGroupSorting());
-            dataManager.packAlignments(renderOptions);
+            alignmentTrack.packAlignments();
             alignmentTrack.repaint();
         });
         groupMenu.add(invertGroupNameSortingOption);
@@ -1288,7 +1314,7 @@ class AlignmentTrackMenu extends IGVPopupMenu {
             }
         }
         renderOptions.setLinkedReads(linkReads);
-        dataManager.packAlignments(renderOptions);
+        alignmentTrack.packAlignments();
         alignmentTrack.repaint();
     }
 
