@@ -69,7 +69,6 @@ public class InsertionManager {
 
     public List<InsertionMarker> getInsertions(String chrName, double start, double end) {
 
-
         Map<Integer, InsertionMarker> insertionMap = insertionMaps.get(chrName);
         if(insertionMap == null ) return null;
 
@@ -81,11 +80,6 @@ public class InsertionManager {
         this.selectedInsertion = insertionMarker;
     }
 
-    public InsertionMarker getSelectedInsertion(String chrName) {
-        return this.selectedInsertion;
-    }
-
-
     public synchronized void processAlignments(String chr, List<Alignment> alignments) {
 
         Genome genome = GenomeManager.getInstance().getCurrentGenome();
@@ -107,7 +101,7 @@ public class InsertionManager {
             AlignmentBlock[] blocks = a.getInsertions();
             if (blocks != null) {
                 for (AlignmentBlock block : blocks) {
-                    if (block.getBases() == null || block.getBases().length < minLength) continue;
+                    if (block.getBasesLength() < minLength) continue;
                     Integer key = block.getStart();
                     InsertionMarker insertionMarker = insertionMap.get(key);
                     if (insertionMarker == null) {
