@@ -94,7 +94,7 @@ public class SpliceJunctionTrack extends FeatureTrack implements ScalableTrack {
         this.dataManager = dataManager;
         this.dataManager.subscribe(this);
         this.alignmentTrack = alignmentTrack;
-        this.strandOption = ignoreStrand;
+        SpliceJunctionTrack.strandOption = ignoreStrand;
     }
 
     public SpliceJunctionTrack() {
@@ -123,8 +123,10 @@ public class SpliceJunctionTrack extends FeatureTrack implements ScalableTrack {
         if (!isShowFeatures(context.getReferenceFrame())) {
             Rectangle visibleRect = context.getVisibleRect().intersection(rect);
             Graphics2D g = context.getGraphic2DForColor(Color.gray);
-            GraphicUtils.drawCenteredText("Zoom in to see features.", visibleRect, g);
-            return;
+            String message = context.getReferenceFrame().getChrName().equals(Globals.CHR_ALL) ?
+                    "Select a chromosome and zoom in to see features." :
+                    "Zoom in to see features.";
+            GraphicUtils.drawCenteredText(message, visibleRect, g);
         } else {
             super.render(context, rect);
         }
@@ -207,11 +209,6 @@ public class SpliceJunctionTrack extends FeatureTrack implements ScalableTrack {
         return 0;
     }
 
-    @Override
-    protected String getZoomInMessage(String chr) {
-        return "Zoom in to see junctions.";
-    }
-
     @Override
     protected void renderFeatures(RenderContext context, Rectangle inputRect) {
 
@@ -239,7 +236,7 @@ public class SpliceJunctionTrack extends FeatureTrack implements ScalableTrack {
     }
 
     public void load(ReferenceFrame frame) {
-        dataManager.load(frame, alignmentTrack.getRenderOptions(), true);
+        dataManager.load(frame, alignmentTrack.getRenderOptions(), alignmentTrack.getDisplayMode(), true);
 
     }
 
