@@ -25,6 +25,7 @@
 
 package org.broad.igv.sashimi;
 
+import org.broad.igv.event.IGVEvent;
 import org.broad.igv.event.IGVEventBus;
 import org.broad.igv.event.IGVEventObserver;
 import org.broad.igv.event.ViewChange;
@@ -49,6 +50,7 @@ import java.awt.geom.Rectangle2D;
 import java.io.File;
 import java.util.List;
 import java.util.*;
+import java.util.stream.Collectors;
 
 /**
  * Window for displaying sashimi style junction plot
@@ -59,6 +61,7 @@ import java.util.*;
  */
 public class SashimiPlot extends JFrame implements IGVEventObserver {
 
+    private final SashimiContentPane sashimiContentPane;
     private List<SpliceJunctionTrack> spliceJunctionTracks;
 
     private ReferenceFrame referenceFrame;
@@ -80,17 +83,19 @@ public class SashimiPlot extends JFrame implements IGVEventObserver {
 
     private static final List<Color> plotColors;
 
+    private Map<Object, SashimiJunctionRenderer> junctionRendererMap;
+
     static {
         ColorPalette palette = ColorUtilities.getDefaultPalette();
         plotColors = Arrays.asList(palette.getColors());
     }
 
-
-    public SashimiPlot(ReferenceFrame iframe, Collection<? extends AlignmentTrack> alignmentTracks, FeatureTrack geneTrack) {
+    public SashimiPlot(ReferenceFrame iframe, Collection<AlignmentTrack> alignmentTracks, FeatureTrack geneTrack) {
 
         // setContentPane(new SashimiContentPane());
         getGlassPane().setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
-        int minJunctionCoverage = PreferencesManager.getPreferences().getAsInt(Constants.SAM_JUNCTION_MIN_COVERAGE);
+        getContentPane().setLayout(new BorderLayout());
+        setBackground(Color.white);
 
         this.eventBus = new IGVEventBus();
         this.referenceFrame = new ReferenceFrame(iframe, eventBus);
@@ -101,21 +106,29 @@ public class SashimiPlot extends JFrame implements IGVEventObserver {
         int height = IGV.hasInstance() ? IGV.getInstance().getMainFrame().getHeight() : 800;
         setSize(referenceFrame.getWidthInPixels(), height);
 
+        //Add control elements to the top
+        final JPanel controlPanel = generateControlPanel(this.referenceFrame);
+        controlPanel.setAlignmentX(Component.CENTER_ALIGNMENT);
+        getContentPane().add(controlPanel, BorderLayout.NORTH);
+
+
         JPanel sashimiPanel = new JPanel();
+        sashimiPanel.setBackground(Color.WHITE);
         BoxLayout boxLayout = new BoxLayout(sashimiPanel, BoxLayout.Y_AXIS);
         sashimiPanel.setLayout(boxLayout);
 
-        //Add control elements to the top
-        sashimiPanel.add(generateControlPanel(this.referenceFrame));
+        // TODO ? Initialize minJunctionCoverage
 
         spliceJunctionTracks = new ArrayList<>(alignmentTracks.size());
+
         int colorInd = 0;
 
+        junctionRendererMap = new HashMap<>();
+
         eventBus.subscribe(ViewChange.class, this);
 
         for (AlignmentTrack alignmentTrack : alignmentTracks) {
 
-
             //AlignmentDataManager oldDataManager = alignmentTrack.getDataManager();
             AlignmentDataManager dataManager = alignmentTrack.getDataManager();
 
@@ -124,16 +137,18 @@ public class SashimiPlot extends JFrame implements IGVEventObserver {
             // Override expand/collpase setting -- expanded sashimi plots make no sense
             spliceJunctionTrack.setDisplayMode(Track.DisplayMode.COLLAPSED);
 
-            spliceJunctionTrack.setRendererClass(SashimiJunctionRenderer.class);
+            SashimiJunctionRenderer renderer = new SashimiJunctionRenderer();
+            spliceJunctionTrack.setRenderer(renderer);
+            junctionRendererMap.put(spliceJunctionTrack, renderer);
 
             Color color = plotColors.get(colorInd);
             colorInd = (colorInd + 1) % plotColors.size();
             spliceJunctionTrack.setColor(color);
 
-            TrackComponent<SpliceJunctionTrack> trackComponent = new TrackComponent<SpliceJunctionTrack>(referenceFrame, spliceJunctionTrack);
+            TrackComponent<SpliceJunctionTrack> trackComponent = new TrackComponent<>(referenceFrame, spliceJunctionTrack);
             trackComponent.originalFrame = iframe;
 
-            initSpliceJunctionComponent(trackComponent, dataManager, dataManager.getCoverageTrack(), minJunctionCoverage);
+            initSpliceJunctionComponent(trackComponent, dataManager, dataManager.getCoverageTrack());
 
             sashimiPanel.add(trackComponent);
             spliceJunctionTracks.add(spliceJunctionTrack);
@@ -145,21 +160,21 @@ public class SashimiPlot extends JFrame implements IGVEventObserver {
         sashimiPanel.add(axis);
 
         SelectableFeatureTrack geneTrackClone = new SelectableFeatureTrack(geneTrack);
-        TrackComponent<SelectableFeatureTrack> geneComponent = new TrackComponent<SelectableFeatureTrack>(referenceFrame, geneTrackClone);
+        TrackComponent<SelectableFeatureTrack> geneComponent = new TrackComponent<>(referenceFrame, geneTrackClone);
         initGeneComponent(referenceFrame.getWidthInPixels(), geneComponent, geneTrackClone);
 
         JScrollPane scrollableGenePane = new JScrollPane(geneComponent);
         scrollableGenePane.setHorizontalScrollBarPolicy(JScrollPane.HORIZONTAL_SCROLLBAR_NEVER);
         scrollableGenePane.setVerticalScrollBarPolicy(JScrollPane.VERTICAL_SCROLLBAR_AS_NEEDED);
 
-        JSplitPane splitPane = new JSplitPane(JSplitPane.VERTICAL_SPLIT, sashimiPanel, scrollableGenePane);
-        splitPane.setDividerLocation(2 * height / 3);
-        getContentPane().add(splitPane);
+        sashimiContentPane = new SashimiContentPane(sashimiPanel, scrollableGenePane);
+        sashimiContentPane.setDividerLocation(2 * height / 3);
+        getContentPane().add(sashimiContentPane);
 
         validate();
     }
 
-    private Component generateControlPanel(ReferenceFrame frame) {
+    private JPanel generateControlPanel(ReferenceFrame frame) {
         JPanel controlPanel = new JPanel();
 
         ZoomSliderPanel zoomSliderPanel = new ZoomSliderPanel(frame);
@@ -180,10 +195,6 @@ public class SashimiPlot extends JFrame implements IGVEventObserver {
         Dimension panelSize = controlSize;
         setFixedSize(controlPanel, panelSize);
 
-
-        BoxLayout layout = new BoxLayout(controlPanel, BoxLayout.X_AXIS);
-        controlPanel.setLayout(layout);
-
         return controlPanel;
     }
 
@@ -218,7 +229,7 @@ public class SashimiPlot extends JFrame implements IGVEventObserver {
         geneComponent.addMouseMotionListener(ad2);
     }
 
-    private void initSpliceJunctionComponent(TrackComponent<SpliceJunctionTrack> trackComponent, AlignmentDataManager dataManager, CoverageTrack coverageTrack, int minJunctionCoverage) {
+    private void initSpliceJunctionComponent(TrackComponent<SpliceJunctionTrack> trackComponent, AlignmentDataManager dataManager, CoverageTrack coverageTrack) {
         JunctionTrackMouseAdapter ad1 = new JunctionTrackMouseAdapter(trackComponent);
         trackComponent.addMouseListener(ad1);
         trackComponent.addMouseMotionListener(ad1);
@@ -226,18 +237,15 @@ public class SashimiPlot extends JFrame implements IGVEventObserver {
         getRenderer(trackComponent.track).setDataManager(dataManager);
         getRenderer(trackComponent.track).setCoverageTrack(coverageTrack);
         getRenderer(trackComponent.track).getCoverageTrack().rescale(trackComponent.originalFrame);
-
-        dataManager.setMinJunctionCoverage(minJunctionCoverage);
-
-        getRenderer(trackComponent.track).setBackground(getBackground());
+        getRenderer(trackComponent.track).setBackground(getBackground());  // <= this is neccessary
     }
 
     private SashimiJunctionRenderer getRenderer(SpliceJunctionTrack spliceJunctionTrack) {
-        return (SashimiJunctionRenderer) spliceJunctionTrack.getRenderer();
+        return junctionRendererMap.get(spliceJunctionTrack);
     }
 
     @Override
-    public void receiveEvent(Object event) {
+    public void receiveEvent(IGVEvent event) {
         repaint();
     }
 
@@ -259,7 +267,7 @@ public class SashimiPlot extends JFrame implements IGVEventObserver {
 
         public void updateToolTipText(TrackClickEvent tce) {
             toolTipText = track.getValueStringAt(tce.getFrame().getChrName(), tce.getChromosomePosition(), tce.getMouseEvent().getX(), tce.getMouseEvent().getY(), tce.getFrame());
-            toolTipText = "<html>" + toolTipText;
+            toolTipText = toolTipText == null ? "" : "<html>" + toolTipText;
             setToolTipText(toolTipText);
         }
 
@@ -274,7 +282,7 @@ public class SashimiPlot extends JFrame implements IGVEventObserver {
 
         @Override
         public Dimension getPreferredSize() {
-            return new Dimension(Integer.MAX_VALUE, track.getHeight());
+            return new Dimension(100, track.getHeight());
         }
     }
 
@@ -288,8 +296,7 @@ public class SashimiPlot extends JFrame implements IGVEventObserver {
      * @param newMinJunctionCoverage
      */
     private void setMinJunctionCoverage(TrackComponent<SpliceJunctionTrack> trackComponent, int newMinJunctionCoverage) {
-        AlignmentDataManager dataManager = getRenderer(trackComponent.track).getDataManager();
-        dataManager.setMinJunctionCoverage(newMinJunctionCoverage);
+
         trackComponent.track.clear();
         trackComponent.repaint();
     }
@@ -324,12 +331,9 @@ public class SashimiPlot extends JFrame implements IGVEventObserver {
 
             final JCheckBoxMenuItem showCoverageData = new JCheckBoxMenuItem("Show Exon Coverage Data");
             showCoverageData.setSelected(PreferencesManager.getPreferences().getAsBoolean(Constants.SASHIMI_SHOW_COVERAGE));
-            showCoverageData.addActionListener(new ActionListener() {
-                @Override
-                public void actionPerformed(ActionEvent e) {
-                    PreferencesManager.getPreferences().put(Constants.SASHIMI_SHOW_COVERAGE, showCoverageData.isSelected());
-                    SashimiPlot.this.repaint();
-                }
+            showCoverageData.addActionListener(e16 -> {
+                PreferencesManager.getPreferences().put(Constants.SASHIMI_SHOW_COVERAGE, showCoverageData.isSelected());
+                SashimiPlot.this.repaint();
             });
 
             CoverageTrack covTrack = getRenderer(this.trackComponent.track).getCoverageTrack();
@@ -340,51 +344,42 @@ public class SashimiPlot extends JFrame implements IGVEventObserver {
             JMenuItem maxJunctionCoverageRange = new JMenuItem("Set Junction Coverage Max");
             maxJunctionCoverageRange.setToolTipText("The thickness of each line will be proportional to the coverage, up until this value");
 
-            maxJunctionCoverageRange.addActionListener(new ActionListener() {
-                @Override
-                public void actionPerformed(ActionEvent e) {
-                    String input = JOptionPane.showInputDialog("Set Max Junction Coverage", getRenderer(trackComponent.track).getMaxDepth());
-                    if (input == null || input.length() == 0) return;
-                    try {
-                        int newMaxDepth = Integer.parseInt(input);
-                        setMaxCoverageDepth(JunctionTrackMouseAdapter.this.trackComponent, newMaxDepth);
-                    } catch (NumberFormatException ex) {
-                        JOptionPane.showMessageDialog(SashimiPlot.this, input + " is not an integer");
-                    }
+            maxJunctionCoverageRange.addActionListener(e12 -> {
+                String input = JOptionPane.showInputDialog(SashimiPlot.this, "Set Max Junction Coverage", getRenderer(trackComponent.track).getMaxDepth());
+                if (input == null || input.length() == 0) return;
+                try {
+                    int newMaxDepth = Integer.parseInt(input);
+                    setMaxCoverageDepth(JunctionTrackMouseAdapter.this.trackComponent, newMaxDepth);
+                } catch (NumberFormatException ex) {
+                    JOptionPane.showMessageDialog(SashimiPlot.this, input + " is not an integer");
                 }
             });
-            JMenuItem minJunctionCoverage = new JMenuItem("Set Junction Coverage Min");
-            minJunctionCoverage.setToolTipText("Junctions below this threshold will be removed from view");
-            minJunctionCoverage.addActionListener(new ActionListener() {
-                @Override
-                public void actionPerformed(ActionEvent e) {
-                    AlignmentDataManager dataManager = getRenderer(trackComponent.track).getDataManager();
-                    SpliceJunctionHelper.LoadOptions loadOptions = dataManager.getSpliceJunctionLoadOptions();
 
-                    String input = JOptionPane.showInputDialog("Set Minimum Junction Coverage", loadOptions.minJunctionCoverage);
-                    if (input == null || input.length() == 0) return;
-                    try {
-                        int newMinJunctionCoverage = Integer.parseInt(input);
-                        setMinJunctionCoverage(JunctionTrackMouseAdapter.this.trackComponent, newMinJunctionCoverage);
-
-                    } catch (NumberFormatException ex) {
-                        JOptionPane.showMessageDialog(SashimiPlot.this, input + " is not an integer");
-                    }
+            JMenuItem minJunctionCoverageItem = new JMenuItem("Set Junction Coverage Min");
+            minJunctionCoverageItem.setToolTipText("Junctions below this threshold will be removed from view");
+            minJunctionCoverageItem.addActionListener(e1 -> {
+                int minCov = this.trackComponent.track.getMinJunctionCoverage();
+                String input = JOptionPane.showInputDialog(SashimiPlot.this, "Set Minimum Junction Coverage", minCov);
+                if (input == null || input.length() == 0) return;
+                try {
+                    int newMinJunctionCoverage = Integer.parseInt(input);
+                    trackComponent.track.setMinJunctionCoverage(newMinJunctionCoverage);
+                    trackComponent.track.clear();
+                    trackComponent.repaint();
+                } catch (NumberFormatException ex) {
+                    JOptionPane.showMessageDialog(SashimiPlot.this, input + " is not an integer");
                 }
             });
 
 
             JMenuItem colorItem = new JMenuItem("Set Color");
-            colorItem.addActionListener(new ActionListener() {
-                @Override
-                public void actionPerformed(ActionEvent e) {
-                    Color color = UIUtilities.showColorChooserDialog(
-                            "Select Track Color", trackComponent.track.getColor());
-                    SashimiPlot.this.toFront();
-                    if (color == null) return;
-                    trackComponent.track.setColor(color);
-                    trackComponent.repaint();
-                }
+            colorItem.addActionListener(e15 -> {
+                Color color = UIUtilities.showColorChooserDialog(
+                        "Select Track Color", trackComponent.track.getColor());
+                SashimiPlot.this.toFront();
+                if (color == null) return;
+                trackComponent.track.setColor(color);
+                trackComponent.repaint();
             });
 
             ButtonGroup shapeGroup = new ButtonGroup();
@@ -426,27 +421,21 @@ public class SashimiPlot extends JFrame implements IGVEventObserver {
 
 
             JMenuItem savePngImageItem = new JMenuItem("Save PNG Image...");
-            savePngImageItem.addActionListener(new ActionListener() {
-                @Override
-                public void actionPerformed(ActionEvent e) {
-                    File defaultFile = new File("Sashimi.png");
-                    IGV.getInstance().createSnapshot(SashimiPlot.this.getContentPane(), defaultFile);
-                }
+            savePngImageItem.addActionListener(e13 -> {
+                File defaultFile = new File("Sashimi.png");
+                IGV.getInstance().createSnapshot(SashimiPlot.this.sashimiContentPane, defaultFile);
             });
 
             JMenuItem saveSvgImageItem = new JMenuItem("Save SVG Image...");
-            saveSvgImageItem.addActionListener(new ActionListener() {
-                @Override
-                public void actionPerformed(ActionEvent e) {
-                    File defaultFile = new File("Sashimi.svg");
-                    IGV.getInstance().createSnapshot(SashimiPlot.this.getContentPane(), defaultFile);
-                }
+            saveSvgImageItem.addActionListener(e14 -> {
+                File defaultFile = new File("Sashimi.svg");
+                IGV.getInstance().createSnapshot(SashimiPlot.this.sashimiContentPane, defaultFile);
             });
 
             // Coverage ranges -- these apply to current plot only
             menu.add(new JLabel("Junction Coverage Display"));
             menu.add(setCoverageDataRange);
-            menu.add(minJunctionCoverage);
+            menu.add(minJunctionCoverageItem);
             menu.add(maxJunctionCoverageRange);
             menu.add(colorItem);
 
@@ -648,13 +637,10 @@ public class SashimiPlot extends JFrame implements IGVEventObserver {
             geneTrack = dlg.getSelectedTrack();
         }
 
-        Collection<AlignmentTrack> alignmentTracks = new ArrayList<AlignmentTrack>();
-        for (Track track : IGV.getInstance().getAllTracks()) {
-            if (track instanceof AlignmentTrack) {
-                alignmentTracks.add((AlignmentTrack) track);
-            }
-        }
 
+        Collection<AlignmentTrack> alignmentTracks = IGV.getInstance().getAlignmentTracks().stream()
+                .filter(t -> t.getExperimentType() == AlignmentTrack.ExperimentType.RNA).collect(Collectors.toList());
+        ;
         if (alignmentTracks.size() > 1) {
             TrackSelectionDialog<AlignmentTrack> alDlg =
                     new TrackSelectionDialog<AlignmentTrack>(IGV.getInstance().getMainFrame(), TrackSelectionDialog.SelectionMode.MULTIPLE, alignmentTracks);
