@@ -246,7 +246,7 @@ public class TDFDataSource implements CoverageDataSource {
 
         List<LocusScore> scores = new ArrayList(10000);
 
-        for (String chr : genome.getAllChromosomeNames()) {
+        for (String chr : genome.getChromosomeNames()) {
             Chromosome c = genome.getChromosome(chr);
 
             String dsName = "/" + chr + "/raw";
@@ -407,10 +407,12 @@ public class TDFDataSource implements CoverageDataSource {
             endLocation = Math.min(chromosome.getLength(), endLocation);
         }
 
-        String querySeq = sequenceNames.contains(chr) ? chr : chromAliasManager.getAliasName(chr);
-
         ArrayList scores = new ArrayList();
 
+        String querySeq = sequenceNames.contains(chr) ? chr : chromAliasManager.getAliasName(chr);
+        if(querySeq == null) return scores;
+
+
         // TODO -- this whole section could be computed once and stored,  it is only a function of the genome, chr, and zoom level.
         int tileWidth = 0;
         if (chr.equals(Globals.CHR_ALL)) {
