@@ -25,20 +25,10 @@
 
 package org.broad.igv.track;
 
+import htsjdk.tribble.Feature;
 import org.broad.igv.feature.genome.Genome;
 import org.broad.igv.feature.genome.GenomeManager;
-import org.broad.igv.tools.FeatureSearcher;
-import org.broad.igv.ui.IGV;
-import org.broad.igv.ui.util.CancellableProgressDialog;
-import org.broad.igv.ui.util.IndefiniteProgressMonitor;
-import org.broad.igv.ui.util.ProgressMonitor;
-import org.broad.igv.util.LongRunningTask;
-import htsjdk.tribble.Feature;
 
-import java.awt.event.ActionEvent;
-import java.awt.event.ActionListener;
-import java.beans.PropertyChangeEvent;
-import java.beans.PropertyChangeListener;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Iterator;
