@@ -53,7 +53,7 @@ import java.util.List;
 public interface Track extends Persistable {
 
     enum DisplayMode {
-        COLLAPSED, SQUISHED, EXPANDED
+        COLLAPSED, SQUISHED, EXPANDED, FULL
     }
 
     /**
@@ -157,6 +157,10 @@ public interface Track extends Persistable {
         return false;
     }
 
+    default boolean isAlignment() {
+        return false;
+    }
+
     void setOverlayed(boolean overlayVisible);
 
     TrackType getTrackType();
