@@ -76,7 +76,6 @@ import org.broad.igv.sam.EWigTrack;
 import org.broad.igv.sam.reader.IndexNotFoundException;
 import org.broad.igv.tdf.TDFDataSource;
 import org.broad.igv.tdf.TDFReader;
-import org.broad.igv.ucsc.Trix;
 import org.broad.igv.ucsc.bb.BBDataSource;
 import org.broad.igv.ucsc.bb.BBFeatureSource;
 import org.broad.igv.ucsc.bb.BBFile;
@@ -227,12 +226,21 @@ public class TrackLoader {
             } else if (format.equals("maf")) {
                 loadMultipleAlignmentTrack(locator, newTracks, genome);
             } else {
+
+                // Try overriding format
+                 String determinedFormat = FileFormatUtils.determineFormat(locator.getPath());
+                 if(determinedFormat != null && !determinedFormat.equals("sampleinfo") && !determinedFormat.equals(format)) {
+                     locator.setFormat(determinedFormat);
+                     return load(locator, genome);
+                 }
+
+
                 // If the file is too large, give up
-                // TODO -- ftp test
                 final int tenMB = 10000000;
                 long fileLength = ParsingUtils.getContentLength(locator.getPath());
                 if (fileLength > tenMB) {
                     MessageUtils.confirm("<html>Cannot determine file type of: " + locator.getPath());
+                    return newTracks;
                 }
 
                 // Read file contents and try to sort it out
@@ -242,7 +250,7 @@ public class TrackLoader {
                 if (CytoBandFileParser.isValid(reader, locator.getPath())) {
                     Track track = new CytobandTrack(locator, new BufferedReader(new StringReader(contents)), genome);
                     newTracks.add(track);
-                } else if (AttributeManager.isSampleInfoFile(reader)) {
+                } else if ("sampleinfo".equals(determinedFormat)) {
                     // This might be a sample information file.
                     AttributeManager.getInstance().loadSampleInfo(locator);
                 } else {
@@ -295,7 +303,7 @@ public class TrackLoader {
         } else {
             return typeString.equals("sam") || typeString.equals("bam") || typeString.equals("cram") ||
                     typeString.equals("sam.list") || typeString.equals("bam.list") ||
-                    typeString.equals("aligned") || typeString.equals("sai") ||
+                    typeString.equals("aligned") || typeString.equals("sai") || typeString.equals("bedz") ||
                     typeString.equals("bai") || typeString.equals("csi") || typeString.equals("alist");
         }
     }
@@ -958,10 +966,10 @@ public class TrackLoader {
                 break;
             }
         }
-        if (genome != null && genome.getAllChromosomeNames() != null && genome.getAllChromosomeNames().size() > 0) {
+        if (genome != null && genome.getChromosomeNames() != null && genome.getChromosomeNames().size() > 0) {
             message.append("<br>Genome: ");
             n = 0;
-            for (String cn : genome.getAllChromosomeNames()) {
+            for (String cn : genome.getChromosomeNames()) {
                 message.append(cn + ", ");
                 n++;
                 if (n > 3) {
