@@ -1,7 +1,6 @@
 package org.broad.igv.ucsc.bb;
 
 import htsjdk.samtools.seekablestream.SeekableStream;
-import htsjdk.tribble.NamedFeature;
 import org.broad.igv.data.BasicScore;
 import org.broad.igv.feature.BasicFeature;
 import org.broad.igv.feature.LocusScore;
@@ -13,6 +12,7 @@ import org.broad.igv.ucsc.Trix;
 import org.broad.igv.ucsc.twobit.UnsignedByteBuffer;
 import org.broad.igv.ucsc.bb.codecs.BBCodec;
 import org.broad.igv.ucsc.bb.codecs.BBCodecFactory;
+import org.broad.igv.ucsc.twobit.UnsignedByteBufferImpl;
 import org.broad.igv.util.CompressionUtils;
 import org.broad.igv.util.stream.IGVSeekableStreamFactory;
 
@@ -82,55 +82,34 @@ import java.util.*;
  */
 public class BBFile {
 
+    enum Type {BIGWIG, BIGBED}
+
     static public final int BBFILE_HEADER_SIZE = 64;
     static public final long BIGWIG_MAGIC = 2291137574l; // BigWig Magic
     static public final long BIGBED_MAGIC = 2273964779l; // BigBed Magic
     static public final int BBFILE_EXTENDED_HEADER_HEADER_SIZE = 64;
     private Trix trix;
-    String autosql;
+    private String autosql;
     private ChromTree chromTree;
     private String[] chrNames;
-    double featureDensity;
-
-    Map<String, String> chrAliasTable;
-    public BBTotalSummary totalSummary;
+    private double featureDensity;
+    private Map<String, String> chrAliasTable;
+    private BBTotalSummary totalSummary;
     private BPTree[] _searchTrees;
-    BBCodec bedCodec;
-
-    public boolean isBigWigFile() {
-        return type == Type.BIGWIG;
-    }
-
-    public boolean isBigBedFile() {
-        return type == Type.BIGBED;
-    }
-
-    public String getAutoSql() {
-        return autosql;
-    }
-
-    public String [] getChromosomeNames() {
-        return chrNames;
-    }
-
-    public void setTrix(Trix trix) {
-    }
-
-
-    enum Type {BIGWIG, BIGBED}
-
-    String path;
-    Type type;
-    BBHeader header = null;
-
-    BBZoomHeader[] zoomHeaders;
-    ByteOrder byteOrder;
-    Genome genome;
+    private Map<Long, RPTree> rTreeCache;
+    private BBCodec bedCodec;
+    private String path;
+    private Type type;
+    private BBHeader header = null;
+    private BBZoomHeader[] zoomHeaders;
+    private ByteOrder byteOrder;
+    private Genome genome;
 
     public BBFile(String path, Genome genome) throws IOException {
         this.path = path;
         this.genome = genome;
         this.chrAliasTable = new HashMap<>();
+        this.rTreeCache = new HashMap<>();
         init();
     }
 
@@ -143,10 +122,45 @@ public class BBFile {
         this.header = readHeader();
     }
 
+    public BBTotalSummary getTotalSummary() {
+        return totalSummary;
+    }
+
+    public Type getType() {
+        return type;
+    }
+
+    public BBHeader getHeader() {
+        return header;
+    }
+
+    public Genome getGenome() {
+        return genome;
+    }
+    public boolean isBigWigFile() {
+        return type == Type.BIGWIG;
+    }
+
+    public boolean isBigBedFile() {
+        return type == Type.BIGBED;
+    }
+
+    public double getFeatureDensity() {
+        return featureDensity;
+    }
+    public String getAutoSQL() {
+        return autosql;
+    }
+
+    public String[] getChromosomeNames() {
+        return chrNames;
+    }
+
     BBHeader readHeader() throws IOException {
 
+        // The common header
         ByteOrder order = ByteOrder.LITTLE_ENDIAN;
-        UnsignedByteBuffer buffer = UnsignedByteBuffer.loadBinaryBuffer(this.path, order, 0, BBFILE_HEADER_SIZE);
+        UnsignedByteBuffer buffer = UnsignedByteBufferImpl.loadBinaryBuffer(this.path, order, 0, BBFILE_HEADER_SIZE);
         long magic = buffer.getUInt();
         if (magic == BIGWIG_MAGIC) {
             this.type = Type.BIGWIG;
@@ -155,7 +169,7 @@ public class BBFile {
         } else {
             //Try big endian order
             order = ByteOrder.BIG_ENDIAN;
-            buffer = UnsignedByteBuffer.loadBinaryBuffer(this.path, order, 0, BBFILE_HEADER_SIZE);
+            buffer = UnsignedByteBufferImpl.loadBinaryBuffer(this.path, order, 0, BBFILE_HEADER_SIZE);
             magic = buffer.getUInt();
             if (magic == BIGWIG_MAGIC) {
                 this.type = Type.BIGWIG;
@@ -180,10 +194,14 @@ public class BBFile {
         header.uncompressBuffSize = buffer.getInt();
         header.extensionOffset = buffer.getLong();
 
-        // Read rest of fields up to full data offset
-        buffer = UnsignedByteBuffer.loadBinaryBuffer(this.path, order, BBFILE_HEADER_SIZE, (int) (header.fullDataOffset - BBFILE_HEADER_SIZE + 4));
+        // Zoom headers, autosql, and total summary if present
+        int size = (int) (header.totalSummaryOffset > 0 ?
+                header.totalSummaryOffset - BBFILE_HEADER_SIZE + 40 :
+                Math.min(header.fullDataOffset, header.chromTreeOffset) - BBFILE_HEADER_SIZE);
 
-        // Zoom headers
+        buffer = UnsignedByteBufferImpl.loadBinaryBuffer(this.path, order, BBFILE_HEADER_SIZE, size);
+
+        // Zoom headers -- immediately follows the common header
         this.zoomHeaders = new BBZoomHeader[header.nZoomLevels];
         for (int i = 0; i < header.nZoomLevels; ++i) {
             BBZoomHeader zlh = new BBZoomHeader();
@@ -196,28 +214,37 @@ public class BBFile {
         // Sort in order of decreasing reduction level (increasing resolution
         Arrays.sort(zoomHeaders, (o1, o2) -> o2.reductionLevel - o1.reductionLevel);
 
-        // Autosql
+        // Autosql -- spec implies this follows the zoom headers
         final int startOffset = BBFILE_HEADER_SIZE;
         if (header.autoSqlOffset > 0) {
             buffer.position((int) (header.autoSqlOffset - startOffset));
             this.autosql = buffer.getString();
         }
 
-        // Total summary -- present in versions >= 2
+        // Total summary -- present in versions >= 2.  Follows the zoom headers and autosql
         if (header.version > 1 && header.totalSummaryOffset > 0) {
             buffer.position((int) (header.totalSummaryOffset - startOffset));
             this.totalSummary = BBTotalSummary.parseSummary(buffer);
         }
 
-        // Chromosome tree
-        // TODO replace with BPTree
-        buffer.position((int) (header.chromTreeOffset - startOffset));
-        this.chromTree = ChromTree.parseTree(buffer, startOffset, this.genome);
+        // Chromosome tree -- we know the start offset but not the size.  But we can try to estimate it.
+        int chromtreeBufferSize =  header.fullDataOffset > header.chromTreeOffset ?
+                (int) Math.min(10000, header.fullDataOffset - header.chromTreeOffset) :
+                10000;
+
+        buffer = UnsignedByteBufferDynamic.loadBinaryBuffer(this.path, order, header.chromTreeOffset, chromtreeBufferSize);
+        this.chromTree = ChromTree.parseTree(buffer, header.chromTreeOffset, this.genome);
         this.chrNames = this.chromTree.names();
 
-        //Total data count -- for bigbed this is the number of features, for bigwig it is number of sections
-        buffer.position((int) (header.fullDataOffset - BBFILE_HEADER_SIZE));
-        header.dataCount = buffer.getInt();
+
+        if (type == Type.BIGBED) {
+            //Total data count -- for bigbed this is the number of features, for bigwig it is number of sections
+            buffer = UnsignedByteBufferImpl.loadBinaryBuffer(this.path, order, header.fullDataOffset, 4);
+            header.dataCount = buffer.getInt();
+            this.featureDensity = ((double) header.dataCount) / chromTree.sumLengths;
+
+            bedCodec = BBCodecFactory.getCodec(autosql, header.definedFieldCount);
+        }
 
         this.header = header;
 
@@ -226,18 +253,6 @@ public class BBFile {
             this.loadExtendedHeader(header.extensionOffset);
         }
 
-        // total summary stats
-        if (header.version > 1) {
-            buffer = UnsignedByteBuffer.loadBinaryBuffer(this.path, order, header.totalSummaryOffset, 40);
-            this.totalSummary = BBTotalSummary.parseSummary(buffer);
-        }
-
-        this.featureDensity = ((double) header.dataCount) / chromTree.sumLengths;
-
-        if (type == Type.BIGBED) {
-            bedCodec = BBCodecFactory.getCodec(autosql, header.definedFieldCount);
-        }
-
 
         return header;
 
@@ -245,7 +260,7 @@ public class BBFile {
 
     void loadExtendedHeader(long offset) throws IOException {
 
-        UnsignedByteBuffer binaryParser = UnsignedByteBuffer.loadBinaryBuffer(this.path, byteOrder, offset, BBFILE_EXTENDED_HEADER_HEADER_SIZE);
+        UnsignedByteBuffer binaryParser = UnsignedByteBufferImpl.loadBinaryBuffer(this.path, byteOrder, offset, BBFILE_EXTENDED_HEADER_HEADER_SIZE);
 
         int extensionSize = binaryParser.getUShort();
         int extraIndexCount = binaryParser.getUShort();
@@ -253,7 +268,7 @@ public class BBFile {
         if (extraIndexCount == 0) return;
 
         int sz = extraIndexCount * (2 + 2 + 8 + 4 + 10 * (2 + 2));
-        binaryParser = UnsignedByteBuffer.loadBinaryBuffer(this.path, byteOrder, extraIndexListOffset, sz);
+        binaryParser = UnsignedByteBufferImpl.loadBinaryBuffer(this.path, byteOrder, extraIndexListOffset, sz);
 
         // const type = []
         // const fieldCount = []
@@ -300,7 +315,12 @@ public class BBFile {
         }
 
         // Load the R Tree and fine leaf items
-        RPTree rpTree = RPTree.loadTree(this.path, treeOffset);
+        RPTree rpTree = rTreeCache.get(treeOffset);
+        if (rpTree == null) {
+            rpTree = RPTree.loadTree(this.path, treeOffset);
+            rTreeCache.put(treeOffset, rpTree);
+        }
+
         List<byte[]> leafChunks = new ArrayList<>();
         List<RPTree.Item> leafItems = rpTree.findLeafItemsOverlapping(chrIdx1, bpStart, chrIdx2, bpEnd);
         if (leafItems != null && leafItems.size() > 0) {
@@ -376,16 +396,21 @@ public class BBFile {
      * @param bpPerPixel -- the resolution in bp per pixel.
      * @return A zoom header, or null if no appropriate zoom data is available for the resolution.
      */
+
     BBZoomHeader zoomLevelForScale(double bpPerPixel) {
+        return zoomLevelForScale(bpPerPixel, 2);
+    }
+
+    BBZoomHeader zoomLevelForScale(double bpPerPixel, int tolerance) {
         BBZoomHeader level = null;
         for (BBZoomHeader zl : this.zoomHeaders) {
             if (zl.reductionLevel < bpPerPixel) {
                 return zl;
             }
         }
-        // For the highest resolution, allow up to a factor of 2
+        // For the lowest resolution, consider a match if within a factor "tolerance" of the requested resolution
         BBZoomHeader lastLevel = this.zoomHeaders[this.zoomHeaders.length - 1];
-        return lastLevel.reductionLevel / 2 < bpPerPixel ? lastLevel : null;
+        return lastLevel.reductionLevel / tolerance < bpPerPixel ? lastLevel : null;
     }
 
     public boolean isSearchable() {
@@ -458,7 +483,7 @@ public class BBFile {
         }
 
 
-        UnsignedByteBuffer bb = UnsignedByteBuffer.wrap(uncompressed, byteOrder);
+        UnsignedByteBufferImpl bb = UnsignedByteBufferImpl.wrap(uncompressed, byteOrder);
         while (bb.remaining() > 0) {
 
             int chromId = bb.getInt();
@@ -488,7 +513,7 @@ public class BBFile {
             uncompressed = buffer;    // use uncompressed read buffer directly
         }
 
-        UnsignedByteBuffer bb = UnsignedByteBuffer.wrap(uncompressed, byteOrder);
+        UnsignedByteBufferImpl bb = UnsignedByteBufferImpl.wrap(uncompressed, byteOrder);
         while (bb.remaining() > 0) {
 
             int chromId = bb.getInt();
@@ -538,7 +563,7 @@ public class BBFile {
             uncompressed = buffer;    // use uncompressed read buffer directly
         }
 
-        UnsignedByteBuffer binaryParser = UnsignedByteBuffer.wrap(uncompressed, byteOrder);
+        UnsignedByteBuffer binaryParser = UnsignedByteBufferImpl.wrap(uncompressed, byteOrder);
         int chromId = binaryParser.getInt();
         int blockStart = binaryParser.getInt();
         int chromStart = blockStart;
