@@ -36,10 +36,14 @@ import org.broad.igv.event.IGVEvent;
 import org.broad.igv.event.IGVEventBus;
 import org.broad.igv.event.IGVEventObserver;
 import org.broad.igv.feature.genome.Genome;
+import org.broad.igv.feature.genome.GenomeListItem;
 import org.broad.igv.feature.genome.GenomeManager;
 import org.broad.igv.feature.genome.GenomeUtils;
 import org.broad.igv.track.AttributeManager;
 import org.broad.igv.track.Track;
+import org.broad.igv.ui.commandbar.GenomeComboBox;
+import org.broad.igv.ui.commandbar.GenomeListManager;
+import org.broad.igv.ui.commandbar.GenomeSelectionDialog;
 import org.broad.igv.util.GoogleUtils;
 import org.broad.igv.oauth.OAuthProvider;
 import org.broad.igv.oauth.OAuthUtils;
@@ -51,7 +55,6 @@ import org.broad.igv.tools.IgvToolsGui;
 import org.broad.igv.tools.motiffinder.MotifFinderPlugin;
 import org.broad.igv.track.CombinedDataSourceDialog;
 import org.broad.igv.ui.action.*;
-import org.broad.igv.ui.commandbar.GenomeComboBox;
 import org.broad.igv.ui.commandbar.RemoveGenomesDialog;
 import org.broad.igv.ui.legend.LegendDialog;
 import org.broad.igv.ui.panel.FrameManager;
@@ -187,21 +190,23 @@ public class IGVMenuBar extends JMenuBar implements IGVEventObserver {
         // by loading a protected Google resource
         try {
             googleMenu = createGoogleMenu();
-            boolean enabled = PreferencesManager.getPreferences().getAsBoolean(ENABLE_GOOGLE_MENU);
-            enableGoogleMenu(enabled);
-            menus.add(googleMenu);
+            if(googleMenu != null) {
+                boolean enabled = PreferencesManager.getPreferences().getAsBoolean(ENABLE_GOOGLE_MENU);
+                enableGoogleMenu(enabled);
+                menus.add(googleMenu);
+            }
         } catch (IOException e) {
             log.error("Error creating google menu: " + e.getMessage());
         }
 
-        try {
-            AWSMenu = createAWSMenu();
-            AWSMenu.setVisible(AmazonUtils.isAwsProviderPresent());
-            menus.add(AWSMenu);
-        } catch (IOException e) {
-            log.error("Error creating the Amazon AWS menu: " + e.getMessage());
-            AWSMenu.setVisible(false);
-        }
+
+        AWSMenu = createAWSMenu();
+        AWSMenu.setVisible(false);
+        menus.add(AWSMenu);
+        //detecting the provider is slow, do it in another thread
+        LongRunningTask.submit(this::updateAWSMenu);
+
+
 
         menus.add(createHelpMenu());
 
@@ -211,7 +216,7 @@ public class IGVMenuBar extends JMenuBar implements IGVEventObserver {
     }
 
     public void updateAWSMenu() {
-        AWSMenu.setVisible(AmazonUtils.isAwsProviderPresent());
+        SwingUtilities.invokeLater(() -> AWSMenu.setVisible(AmazonUtils.isAwsProviderPresent()));
     }
 
     /**
@@ -292,7 +297,7 @@ public class IGVMenuBar extends JMenuBar implements IGVEventObserver {
         menuAction = new LoadFromServerAction("Load From Server...", KeyEvent.VK_S, igv);
         menuAction.setToolTipText(UIConstants.LOAD_SERVER_DATA_TOOLTIP);
         loadTracksFromServerMenuItem = MenuAndToolbarUtils.createMenuItem(menuAction);
-        loadTracksFromServerMenuItem.setVisible(genomeId != null && LoadFromServerAction.getNodeURLs(genomeId) != null);
+       // loadTracksFromServerMenuItem.setVisible(genomeId != null && LoadFromServerAction.getNodeURLs(genomeId) != null);
         menuItems.add(loadTracksFromServerMenuItem);
 
         // Track hubs -- moved to Genomes menu
@@ -448,7 +453,7 @@ public class IGVMenuBar extends JMenuBar implements IGVEventObserver {
 
                 // If a file selection was made
                 if (file != null) {
-                    GenomeManager.getInstance().loadGenome(file.getAbsolutePath());
+                    Genome newGenome = GenomeManager.getInstance().loadGenome(file.getAbsolutePath());
                 }
             } catch (Exception ex) {
                 MessageUtils.showErrorMessage(ex.getMessage(), ex);
@@ -471,11 +476,9 @@ public class IGVMenuBar extends JMenuBar implements IGVEventObserver {
 
         MenuAction menuAction = new SelectGenomeAnnotationTracksAction("Select GenArk Tracks...", igv);
         selectGenomeAnnotationsItem = MenuAndToolbarUtils.createMenuItem(menuAction);
-        Genome genome = GenomeManager.getInstance().getCurrentGenome();
-        selectGenomeAnnotationsItem.setEnabled(genome != null && genome.getHub() != null);
+        Genome newGenome = GenomeManager.getInstance().getCurrentGenome();
+        selectGenomeAnnotationsItem.setEnabled(newGenome != null && newGenome.getHub() != null);
         menu.add(selectGenomeAnnotationsItem);
-
-
         menu.add(new JSeparator());
 
         // Add genome to combo box from server
@@ -963,7 +966,7 @@ public class IGVMenuBar extends JMenuBar implements IGVEventObserver {
         return menu;
     }
 
-    private JMenu createAWSMenu() throws IOException {
+    private JMenu createAWSMenu() {
 
         boolean usingCognito = AmazonUtils.GetCognitoConfig() != null;
 
@@ -1049,12 +1052,20 @@ public class IGVMenuBar extends JMenuBar implements IGVEventObserver {
 
     private JMenu createGoogleMenu() {
 
+        final OAuthProvider googleProvider = OAuthUtils.getInstance().getGoogleProvider();
+        if(googleProvider == null) {
+            log.error("Error creating google oauth provider");
+            return null;
+        }
+
+
         googleMenu = new JMenu("Google");
 
         final JMenuItem login = new JMenuItem("Login ... ");
+
         login.addActionListener(e -> {
             try {
-                OAuthUtils.getInstance().getGoogleProvider().openAuthorizationPage();
+                googleProvider.openAuthorizationPage();
             } catch (Exception ex) {
                 MessageUtils.showErrorMessage("Error fetching oAuth tokens.  See log for details", ex);
                 log.error("Error fetching oAuth tokens", ex);
@@ -1065,7 +1076,7 @@ public class IGVMenuBar extends JMenuBar implements IGVEventObserver {
 
         final JMenuItem logout = new JMenuItem("Logout ");
         logout.addActionListener(e -> {
-            OAuthUtils.getInstance().getGoogleProvider().logout();
+            googleProvider.logout();
             GoogleUtils.setProjectID(null);
         });
         googleMenu.add(logout);
@@ -1077,10 +1088,9 @@ public class IGVMenuBar extends JMenuBar implements IGVEventObserver {
         googleMenu.addMenuListener(new MenuListener() {
             @Override
             public void menuSelected(MenuEvent e) {
-                OAuthProvider oauth = OAuthUtils.getInstance().getGoogleProvider();
-                boolean loggedIn = oauth.isLoggedIn();
-                if (loggedIn && oauth.getCurrentUserName() != null) {
-                    login.setText(oauth.getCurrentUserName());
+                boolean loggedIn = googleProvider.isLoggedIn();
+                if (loggedIn && googleProvider.getCurrentUserName() != null) {
+                    login.setText(googleProvider.getCurrentUserName());
                 } else {
                     login.setText("Login ...");
                 }
@@ -1112,7 +1122,9 @@ public class IGVMenuBar extends JMenuBar implements IGVEventObserver {
      * @throws IOException
      */
     public void enableGoogleMenu(boolean enable) throws IOException {
-        googleMenu.setVisible(enable);
+        if(googleMenu != null) {
+            googleMenu.setVisible(enable);
+        }
     }
 
 //    public void enableRemoveGenomes() {
@@ -1191,8 +1203,6 @@ public class IGVMenuBar extends JMenuBar implements IGVEventObserver {
             UIUtilities.invokeOnEventThread(() -> {
                 final Genome genome = ((GenomeChangeEvent) event).genome();
                 encodeMenuItem.setVisible(EncodeFileBrowser.genomeSupported(genome.getId()));
-                loadTracksFromServerMenuItem.setVisible(LoadFromServerAction.getNodeURLs(genome.getId()) != null);
-                //selectGenomeAnnotationsItem .setEnabled(genome != null && genome.getHub() != null);
             });
         }
     }
