@@ -227,7 +227,7 @@ public class ResourceTree {
         if (infoLink == null) {
             infoLink = getAttribute(xmlNode, INFOLINK.getText());
         }
-        locator.setTrackInforURL(infoLink);
+        locator.setTrackInfoURL(infoLink);
 
         if (xmlNode.getTagName().equalsIgnoreCase("Resource")) {
 
@@ -242,6 +242,7 @@ public class ResourceTree {
             locator.setIndexPath(getAttribute(xmlNode, INDEX.getText()));
             locator.setSampleId(sampleId);
             locator.setFeatureInfoURL(getAttribute(xmlNode, URL.getText()));
+            locator.setLabelField(getAttribute(xmlNode, LABEL_FIELD.getText()));
             locator.setDescription(getAttribute(xmlNode, DESCRIPTION.getText()));
             locator.setTrackLine(getAttribute(xmlNode, TRACK_LINE.getText()));
             locator.setName(name);
