@@ -49,7 +49,10 @@ public class UIConstants {
 
     // Menu tooltips
     static final public String LOAD_TRACKS_TOOLTIP = "Load tracks or sample information";
+
+    static final public String LOAD_HTSGET_TOOLTOP = "Load BAM or VCF tracks from an htsget server";
     static final public String LOAD_SERVER_DATA_TOOLTIP = "Load tracks or sample information from a server";
+    static final public String LOAD_TRACKHUB_TOOLTIP = "Load an assemlby and tracks from a UCSC Track Hub";
     static final public String SAVE_PNG_IMAGE_TOOLTIP = "Capture and save a PNG image";
     static final public String SAVE_SVG_IMAGE_TOOLTIP = "Capture and save an SVG image";
     static final public String NEW_SESSION_TOOLTIP = "Create a new session";
@@ -91,7 +94,7 @@ public class UIConstants {
     final public static String OVERWRITE_SESSION_MESSAGE =
             "<html>Opening a session will unload all current data. " + "<br>Are you sure you wish to continue?";
     final public static String CANNOT_ACCESS_SERVER_GENOME_LIST = "The Genome server is currently inaccessible.";
-    final public static int NUMBER_OF_RECENT_SESSIONS_TO_LIST = 3;
+    final public static int NUMBER_OF_RECENT_SESSIONS_TO_LIST = 10;
     final public static String DEFAULT_SESSION_FILE = "igv_session" + Globals.SESSION_FILE_EXTENSION;
     static final public String SERVER_BASE_URL = "http://www.broadinstitute.org/";
     static final public Color LIGHT_YELLOW = new Color(255, 244, 201);
