@@ -29,12 +29,12 @@
  */
 package org.broad.igv.ui.action;
 
-import org.apache.log4j.Logger;
+import org.broad.igv.logging.LogManager;
+import org.broad.igv.logging.Logger;
 import org.broad.igv.prefs.PreferencesManager;
 import org.broad.igv.ui.IGV;
-import org.broad.igv.ui.UIConstants;
 import org.broad.igv.ui.util.FileDialogUtils;
-import org.broad.igv.util.FileUtils;
+import org.broad.igv.util.LongRunningTask;
 
 import javax.swing.*;
 import java.awt.event.ActionEvent;
@@ -50,21 +50,26 @@ import java.io.File;
  */
 public class OpenSessionMenuAction extends MenuAction {
 
-    private static Logger log = Logger.getLogger(OpenSessionMenuAction.class);
-    private IGV mainFrame;
+    private static Logger log = LogManager.getLogger(OpenSessionMenuAction.class);
+    private IGV igv;
     private String sessionFile = null;
     private boolean autoload = false;
 
-    public OpenSessionMenuAction(String label, String sessionFile, IGV mainFrame) {
-        super(label);
+    /**
+     * Constructor for hardcoded session list at bottom of menu.   This convention is odd, legacy thing.
+     * @param sessionFile
+     * @param igv
+     */
+    public OpenSessionMenuAction(String sessionFile, IGV igv) {
+        super(sessionFile);
         this.sessionFile = sessionFile;
-        this.mainFrame = mainFrame;
+        this.igv = igv;
         autoload = true;
     }
 
-    public OpenSessionMenuAction(String label, int mnemonic, IGV mainFrame) {
+    public OpenSessionMenuAction(String label, int mnemonic, IGV igv) {
         super(label, null, mnemonic);
-        this.mainFrame = mainFrame;
+        this.igv = igv;
     }
 
     @Override
@@ -80,22 +85,9 @@ public class OpenSessionMenuAction extends MenuAction {
             sessionFile = tmpFile.getAbsolutePath();
             PreferencesManager.getPreferences().setLastTrackDirectory(tmpFile.getParentFile());
         }
-        doRestoreSession();
-
-
-    }
-
-    final public void doRestoreSession() {
         if (sessionFile != null) {
-            if (FileUtils.isRemote(sessionFile)) {
-                boolean merge = false;
-                mainFrame.doRestoreSession(sessionFile, null, merge);
-            } else {
-                File f = new File(sessionFile);
-                mainFrame.doRestoreSession(f, null);
-            }
+            LongRunningTask.submit(() -> this.igv.loadSession(sessionFile, null));
         }
     }
-
 }
 
