@@ -10,6 +10,7 @@ import java.awt.*;
 import java.awt.geom.Rectangle2D;
 import java.util.ArrayList;
 import java.util.List;
+import java.util.stream.Collectors;
 
 /**
  * Created by jrobinso on 7/6/17.
@@ -39,7 +40,8 @@ public class ChromosomeComboBox extends JComboBox {
 
         UIUtilities.invokeAndWaitOnEventThread(() -> {
 
-            List<String> allChromosomeNames = genome.getAllChromosomeNames();
+            List<String> allChromosomeNames = genome.getChromosomeNames().stream().map(chr -> genome.getChromosomeDisplayName(chr)).collect(Collectors.toList());
+
             if (allChromosomeNames.size() > 1) {
                 this.setVisible(true);
 
