@@ -39,9 +39,9 @@ public class GenomeListManager {
     private static final String ACT_USER_DEFINED_GENOME_LIST_FILE = "user-defined-genomes.txt";
 
     public static final GenomeListItem DEFAULT_GENOME = new GenomeListItem(
-            "Human (hg19)",
-            "https://s3.amazonaws.com/igv.org.genomes/hg19/hg19.json",
-            "hg19");
+            "Human (hg38)",
+            "https://igv-genepattern-org.s3.amazonaws.com/genomes/hg38/hg38.json",
+            "hg38");
 
     private Map<String, GenomeListItem> genomeItemMap;
 
@@ -258,15 +258,28 @@ public class GenomeListManager {
                         JsonObject json = rootElement.getAsJsonObject();
                         JsonElement id = json.get("id");
                         JsonElement name = json.get("name");
-                        JsonElement fastaURL = json.get("fastaURL");
-                        if (id != null && name != null && fastaURL != null) {
-                            if (cachedGenomes.containsKey(id.getAsString())) {
-                                File prevFile = new File(cachedGenomes.get(id.getAsString()).getPath());
-                                prevFile.delete();
-                            }
-                            GenomeListItem item = new GenomeListItem(name.getAsString(), file.getAbsolutePath(), id.getAsString());
-                            cachedGenomes.put(item.getId(), item);
+                        JsonElement fasta = json.get("fastaURL");
+                        JsonElement twobit = json.get("twoBitURL");
+                        if (id == null) {
+                            log.error("Error parsing " + file.getName() + ". \"id\" is required");
+                            continue;
                         }
+                        if (name == null) {
+                            log.error("Error parsing " + file.getName() + ". \"name\" is required");
+                            continue;
+                        }
+                        if (id == null) {
+                            log.error("Error parsing " + file.getName() + ". \"id\" is required");
+                            continue;
+                        }
+                        if (fasta == null && twobit == null) {
+                            log.error("Error parsing " + file.getName() + ". One of either \"fastaURL\" or \"twoBitURL\" is required");
+                            continue;
+                        }
+
+                        GenomeListItem item = new GenomeListItem(name.getAsString(), file.getAbsolutePath(), id.getAsString());
+                        cachedGenomes.put(item.getId(), item);
+
                     }
                 } catch (Exception e) {
                     log.error("Error parsing genome json: " + file.getAbsolutePath(), e);
@@ -311,9 +324,19 @@ public class GenomeListManager {
 
 
     public void removeGenomeListItem(GenomeListItem genomeListItem) {
-
         final String id = genomeListItem.getId();
         genomeItemMap.remove(id);
+
+        // If this is a cached genome remove it from cache
+        Map<String, GenomeListItem> cachedItems = getCachedGenomeList();
+        if (cachedItems.containsKey(id)) {
+            try {
+                (new File(genomeListItem.getPath())).delete();
+            } catch (Exception e) {
+                log.error("Error deleting genome file: " + genomeListItem.getPath() + ": " + e.getMessage());
+            }
+        }
+
         removeUserDefinedGenome(id);
     }
 
