@@ -25,13 +25,13 @@
 
 
 /*
-* TrackPanel.java
-*
-* Created on Sep 5, 2007, 4:09:39 PM
-*
-* To change this template, choose Tools | Templates
-* and open the template in the editor.
-*/
+ * TrackPanel.java
+ *
+ * Created on Sep 5, 2007, 4:09:39 PM
+ *
+ * To change this template, choose Tools | Templates
+ * and open the template in the editor.
+ */
 
 package org.broad.igv.ui.panel;
 
@@ -42,21 +42,21 @@ import org.broad.igv.prefs.PreferencesManager;
 import org.broad.igv.track.AttributeManager;
 import org.broad.igv.ui.FontManager;
 import org.broad.igv.ui.IGV;
+import org.broad.igv.ui.util.IGVMouseInputAdapter;
 
 import javax.swing.*;
 import javax.swing.event.MouseInputAdapter;
 import java.awt.*;
 import java.awt.event.MouseEvent;
 import java.awt.geom.AffineTransform;
-import java.util.HashMap;
+import java.util.*;
 import java.util.List;
-import java.util.Map;
 
 /**
  * @author jrobinso
  */
 public class AttributeHeaderPanel extends JPanel implements Paintable {
-    
+
     final static int MAXIMUM_FONT_SIZE = 10;
     public final static int ATTRIBUTE_COLUMN_WIDTH = 10;
     public final static int COLUMN_BORDER_WIDTH = 1;
@@ -65,7 +65,8 @@ public class AttributeHeaderPanel extends JPanel implements Paintable {
 
 
     public AttributeHeaderPanel() {
-        setBorder(javax.swing.BorderFactory.createLineBorder(Color.black));
+        setBackground(new java.awt.Color(255, 255, 255));
+        setBorder(javax.swing.BorderFactory.createLineBorder(Color.lightGray));
         setCursor(Cursor.getPredefinedCursor(Cursor.HAND_CURSOR));
         addMouseListener();
     }
@@ -75,7 +76,6 @@ public class AttributeHeaderPanel extends JPanel implements Paintable {
         return ATTRIBUTE_COLUMN_WIDTH;
     }
 
-
     private String getAttributeHeading(int x) {
         int idx = x / (ATTRIBUTE_COLUMN_WIDTH + COLUMN_BORDER_WIDTH);
         List<String> keys = AttributeManager.getInstance().getVisibleAttributes();
@@ -91,12 +91,11 @@ public class AttributeHeaderPanel extends JPanel implements Paintable {
 
         super.paintComponent(graphics);
 
-
         List<String> keys = AttributeManager.getInstance().getVisibleAttributes();
 
         if (keys != null && keys.size() > 0) {
 
-            final Graphics2D graphics2 = (Graphics2D) graphics;
+            final Graphics2D graphics2 = (Graphics2D) graphics.create();
             if (PreferencesManager.getPreferences().getAntiAliasing()) {
                 graphics2.setRenderingHint(RenderingHints.KEY_TEXT_ANTIALIASING, RenderingHints.VALUE_TEXT_ANTIALIAS_ON);
             }
@@ -110,7 +109,7 @@ public class AttributeHeaderPanel extends JPanel implements Paintable {
                 fontSize = MAXIMUM_FONT_SIZE;
             }
             Font font = FontManager.getFont(fontSize);
-            
+
             FontMetrics fm = graphics2.getFontMetrics();
             int fontAscent = fm.getHeight();
 
@@ -132,6 +131,8 @@ public class AttributeHeaderPanel extends JPanel implements Paintable {
                 int stringOffset = 2;
                 graphics2.drawString(toDraw, stringOffset, x);
             }
+
+            graphics2.dispose();
         }
     }
 
@@ -140,10 +141,10 @@ public class AttributeHeaderPanel extends JPanel implements Paintable {
 
         setToolTipText("Click attribute heading to sort");
 
-        MouseInputAdapter listener = new MouseInputAdapter() {
+        MouseInputAdapter listener = new IGVMouseInputAdapter() {
 
             @Override
-            public void mouseClicked(MouseEvent e) {
+            public void igvMouseClicked(MouseEvent e) {
 
                 String attKey = getAttributeHeading(e.getX());
                 if (attKey != null) {
@@ -182,22 +183,26 @@ public class AttributeHeaderPanel extends JPanel implements Paintable {
         addMouseListener(listener);
     }
 
-
     final public void sortTrackByAttribute(String sortKey, boolean isSortAscending) {
 
         if (sortKey != null) {
             IGV.getInstance().sortAllTracksByAttributes(new String[]{sortKey}, new boolean[]{isSortAscending});
-            IGV.getMainFrame().repaint();
+            IGV.getInstance().getMainFrame().repaint();
         }
     }
 
-    public void paintOffscreen(Graphics2D g, Rectangle rect) {
+    public void paintOffscreen(Graphics2D g, Rectangle rect, boolean batch) {
+
+        Graphics2D borderGraphics = (Graphics2D) g.create();
         paintComponent(g);
-
-        Color c = g.getColor();
-        g.setColor(Color.darkGray);
-        g.drawRect(rect.x, rect.y, rect.width, rect.height);
-        g.setColor(c);            //super.paintBorder(g);
-
+        borderGraphics.setColor(Color.lightGray);
+        borderGraphics.drawRect(rect.x, rect.y, rect.width-1, rect.height-1);
+        borderGraphics.dispose();
     }
+
+    @Override
+    public int getSnapshotHeight(boolean batch) {
+        return this.getHeight();
+    }
+
 }
