@@ -41,6 +41,7 @@ import org.broad.igv.event.IGVEventBus;
 import org.broad.igv.event.ViewChange;
 import org.broad.igv.feature.Chromosome;
 import org.broad.igv.feature.Cytoband;
+import org.broad.igv.feature.genome.GenomeManager;
 import org.broad.igv.prefs.PreferencesManager;
 import org.broad.igv.renderer.CytobandRenderer;
 import org.broad.igv.ui.WaitCursorManager;
@@ -104,7 +105,7 @@ public class CytobandPanel extends JPanel {
         if (chromosome == null) {
             return;
         }
-        currentCytobands = chromosome.getCytobands();
+        currentCytobands = GenomeManager.getInstance().getCurrentGenome().getCytobands(getReferenceFrame().getChrName());
         if (currentCytobands == null) {
             return;
         }
@@ -145,6 +146,7 @@ public class CytobandPanel extends JPanel {
 
         MouseInputAdapter mouseAdapter = new IGVMouseInputAdapter() {
 
+            private final ReferenceFrame referenceFrame = getReferenceFrame();
             int lastMousePressX;
             double viewOrigin;
             double viewEnd;
@@ -159,14 +161,13 @@ public class CytobandPanel extends JPanel {
 
                     double newLocation = cytobandScale * mouseX;
                     if (clickCount > 1) {
-                        final int newZoom = getReferenceFrame().getZoom() + 1;
-                        getReferenceFrame().doSetZoomCenter(newZoom, newLocation);
+                        final int newZoom = referenceFrame.getZoom() + 1;
+                        referenceFrame.doSetZoomCenter(newZoom, newLocation);
                     } else {
-                        getReferenceFrame().centerOnLocation(newLocation);
+                        referenceFrame.centerOnLocation(newLocation);
                     }
 
-                    ViewChange result = ViewChange.Result();
-                    result.setRecordHistory(true);
+                    ViewChange result = ViewChange.LocusChangeResult(referenceFrame.chrName, referenceFrame.origin, referenceFrame.getEnd(), true);
                     IGVEventBus.getInstance().post(result);
 
                 } finally {
@@ -190,13 +191,12 @@ public class CytobandPanel extends JPanel {
                 if (isDragging) {
                     WaitCursorManager.CursorToken token = WaitCursorManager.showWaitCursor();
                     try {
-                        getReferenceFrame().setOrigin(viewOrigin);
-                        getReferenceFrame().recordHistory();
+                        referenceFrame.setOrigin(viewOrigin);
+                        referenceFrame.recordHistory();
                     } finally {
                         WaitCursorManager.removeWaitCursor(token);
                     }
-                    ViewChange result = ViewChange.Result();
-                    result.setRecordHistory(true);
+                    ViewChange result = ViewChange.LocusChangeResult(referenceFrame.chrName, referenceFrame.origin, referenceFrame.getEnd(), true);
                     IGVEventBus.getInstance().post(result);
                 }
                 isDragging = false;
