@@ -25,7 +25,9 @@
 
 package org.broad.igv.ui.panel;
 
+import htsjdk.samtools.util.Locatable;
 import org.broad.igv.event.GenomeChangeEvent;
+import org.broad.igv.event.IGVEvent;
 import org.broad.igv.event.IGVEventBus;
 import org.broad.igv.event.IGVEventObserver;
 import org.broad.igv.feature.Locus;
@@ -36,15 +38,22 @@ import org.broad.igv.feature.genome.GenomeManager;
 import org.broad.igv.lists.GeneList;
 import org.broad.igv.prefs.Constants;
 import org.broad.igv.prefs.PreferencesManager;
-import org.broad.igv.session.Session;
 import org.broad.igv.track.RegionScoreType;
 import org.broad.igv.track.Track;
 import org.broad.igv.ui.IGV;
 import org.broad.igv.ui.action.SearchCommand;
 import org.broad.igv.ui.util.MessageUtils;
 
-import java.util.*;
+import java.util.ArrayList;
+import java.util.Arrays;
+import java.util.Comparator;
+import java.util.HashSet;
+import java.util.List;
+import java.util.Set;
+import org.broad.igv.sam.AlignmentTrack;
+import org.broad.igv.sam.SortOption;
 import java.util.stream.Collectors;
+import java.util.stream.Stream;
 
 /**
  * @author jrobinso
@@ -52,7 +61,21 @@ import java.util.stream.Collectors;
  */
 public class FrameManager implements IGVEventObserver {
 
-    private static List<ReferenceFrame> frames = new ArrayList();
+    public static final Comparator<String> FRAME_COMPARATOR = (n0, n1) -> {
+        ReferenceFrame f0 = getFrame(n0);
+        ReferenceFrame f1 = getFrame(n1);
+
+        String chr0 = f0 == null ? "" : f0.getChrName();
+        String chr1 = f1 == null ? "" : f1.getChrName();
+        int s0 = f0 == null ? 0 : f0.getCurrentRange().getStart();
+        int s1 = f1 == null ? 0 : f1.getCurrentRange().getStart();
+
+        int chrComp = ChromosomeNameComparator.get().compare(chr0, chr1);
+        if (chrComp != 0) return chrComp;
+        return s0 - s1;
+    };
+
+    private static List<ReferenceFrame> frames = new ArrayList<>();
     private static ReferenceFrame defaultFrame;
 
     public static final String DEFAULT_FRAME_NAME = "genome";
@@ -139,7 +162,7 @@ public class FrameManager implements IGVEventObserver {
         if (gl == null) {
             frames.add(getDefaultFrame());
         } else {
-            List<String> lociNotFound = new ArrayList();
+            List<String> lociNotFound = new ArrayList<>();
             List<String> loci = gl.getLoci();
             if (loci.size() == 1) {
                 Locus locus = getLocus(loci.get(0));
@@ -246,18 +269,14 @@ public class FrameManager implements IGVEventObserver {
     }
 
     public static void sortFrames(final Track t) {
-
-        Collections.sort(frames, new Comparator<ReferenceFrame>() {
-            @Override
-            public int compare(ReferenceFrame o1, ReferenceFrame o2) {
-                float s1 = t.getRegionScore(o1.getChromosome().getName(), (int) o1.getOrigin(), (int) o1.getEnd(),
-                        o1.getZoom(), RegionScoreType.SCORE, o1.getName());
-                float s2 = t.getRegionScore(o2.getChromosome().getName(), (int) o2.getOrigin(), (int) o2.getEnd(),
-                        o2.getZoom(), RegionScoreType.SCORE, o2.getName());
-                return (s1 == s2 ? 0 : (s1 > s2) ? -1 : 1);
-            }
-        });
-
+        frames.sort(Comparator.comparingDouble((ReferenceFrame f) ->
+                t.getRegionScore(f.getChromosome().getName(),
+                        (int) f.getOrigin(),
+                        (int) f.getEnd(),
+                        f.getZoom(),
+                        RegionScoreType.SCORE,
+                        f.getName()))
+                .reversed());
     }
 
     /**
@@ -338,49 +357,81 @@ public class FrameManager implements IGVEventObserver {
             }
         }
 
-        GeneList geneList = new GeneList("Current frames", loci, false);
-        Session currentSession = IGV.getInstance().getSession();
-        currentSession.setCurrentGeneList(geneList);
-
-        // sort the frames by position
-        currentSession.sortGeneList((n0, n1) -> {
-            ReferenceFrame f0 = getFrame(n0);
-            ReferenceFrame f1 = getFrame(n1);
-
-            String chr0 = f0 == null ? "" : f0.getChrName();
-            String chr1 = f1 == null ? "" : f1.getChrName();
-            int s0 = f0 == null ? 0 : f0.getCurrentRange().getStart();
-            int s1 = f1 == null ? 0 : f1.getCurrentRange().getStart();
-
-            int chrComp = ChromosomeNameComparator.get().compare(chr0, chr1);
-            if (chrComp != 0) return chrComp;
-            return s0 - s1;
-        });
+        //Need to sort the frames by position
+        GeneList geneList = new GeneList("Current frames", loci);
+        geneList.sort(FRAME_COMPARATOR);
+        IGV.getInstance().getSession().setCurrentGeneList(geneList);
         IGV.getInstance().resetFrames();
     }
 
+    /*
+     * todo: this shoold be combined with addFrames since they do confusingly similar things
+     *  This takes an arbitrary number of new locations to add as well as a single existing frame to keep
+     *      (possibly that's ignored if there are multiple reference frames due to how loci are processed in createLociList())
+     *  It doesn't merge overlapping frames like addFrames does which it probably should.
+     */
+
+    /**
+     * Open new frames displaying the locations included in toIncludeInSplit
+     * @param frame this is used to set the width of the new frames to be consistent
+     * @param toIncludeInSplit new locations to open frames for
+     * @param selectedReadNames a set of read names which will be sorted to the top of the open frames
+     */
+    public static void addNewLociToFrames(final ReferenceFrame frame, final List<? extends Locatable> toIncludeInSplit, final Set<String> selectedReadNames) {
+        final Stream<String> newLoci = toIncludeInSplit.stream().map(locatable -> getLocusStringScaledToFrame(frame, locatable));
+        final Stream<String> existingFrames = getFrames().stream().map(ref -> {
+            String name = ref.getName();
+            return Locus.fromString(name) != null ? name : ref.getFormattedLocusString();
+        });
+
+        //Can't use FRAME_COMPARATOR because that looks at the existing frames statically and they don't all exist yet
+        final Comparator<String> comparator = Comparator.comparing(Locus::fromString, SortOption.POSITION_COMPARATOR);
+
+        final List<String> loci = Stream.concat(newLoci, existingFrames)
+                .sorted(comparator)
+                .distinct()
+                .collect(Collectors.toList());
+        String listName = String.join("   ", loci);
+        //Need to sort the frames by position
+        GeneList geneList = new GeneList(listName, loci);
+        geneList.sort(comparator);
+        IGV.getInstance().getSession().setCurrentGeneList(geneList);
+        IGV.getInstance().resetFrames();
+
+        /*
+        We want the sort to happen after the frame refresh / track loading begins.
+        This puts the sort onto the event thread so that it happens after loading has already started.
+        Since loading reads happens asynchronously on a different thread from the event thread, it is likely
+        that the loading won't be done by the time the sort fires.  In that case the sort will be set as the
+        action to perform when the load is finished
+        See {@link AlignmentTrack#sortRows(SortOption, Double, String, boolean, Set)}
+        */
+        AlignmentTrack.sortSelectedReadsToTheTop(selectedReadNames);
+    }
+
+    private static String getLocusStringScaledToFrame(final ReferenceFrame frame, final Locatable alignment) {
+        int adjustedMateStart = alignment.getStart() - 1;
+
+        // Generate a locus string for the alignment.  Keep the window width (in base pairs) == to the current range
+        Range range = frame.getCurrentRange();
+        int length = range.getLength();
+        int start = Math.max(0, adjustedMateStart - length / 2);
+        int end = start + length;
+        return alignment.getContig() + ":" + start + "-" + end;
+    }
+
 
     @Override
-    public void receiveEvent(Object event) {
-        if (event instanceof GenomeChangeEvent) {
-            Genome newGenome = ((GenomeChangeEvent) event).genome;
+    public void receiveEvent(IGVEvent event) {
+        if (event instanceof final GenomeChangeEvent e) {
+            Genome newGenome = e.genome();
             boolean force = true;
             getDefaultFrame().setChromosomeName(newGenome.getHomeChromosome(), force);
         }
     }
 
 
-    public static class ChangeEvent {
-        List<ReferenceFrame> frames;
-
-        public ChangeEvent(List<ReferenceFrame> frames) {
-            this.frames = frames;
-        }
-
-        public List<ReferenceFrame> getFrames() {
-            return frames;
-        }
-    }
+    public record ChangeEvent(List<ReferenceFrame> frames) implements IGVEvent {}
 
 }
 
