@@ -413,23 +413,30 @@ public class MainPanel extends JPanel implements Paintable {
 
     public void removeDataPanel(String name) {
 
-        TrackPanelScrollPane sp = null;
         for (TrackPanel tp : getTrackPanels()) {
             if (name.equals(tp.getName())) {
-                sp = tp.getScrollPane();
-                break;
+                removeTrackPanel(tp);
+                return;
             }
         }
+    }
+
+    public void removeTrackPanel(TrackPanel trackPanel) {
         // Don't remove the "special" panes
-        if (sp == dataTrackScrollPane || sp == featureTrackScrollPane) {
-            return;
-        }
-        if (sp != null) {
-            centerSplitPane.remove(sp);
-            TrackNamePanel.removeDropListenerFor(sp.getNamePanel());
+        if (panelIsRemovable(trackPanel)) {
+            TrackPanelScrollPane sp = trackPanel.getScrollPane();
+            if (sp != null) {
+                centerSplitPane.remove(sp);
+                TrackNamePanel.removeDropListenerFor(sp.getNamePanel());
+                centerSplitPane.revalidate();
+            }
         }
     }
 
+    public boolean panelIsRemovable(TrackPanel trackPanel) {
+        return trackPanel.getScrollPane() != dataTrackScrollPane && trackPanel.getScrollPane() != featureTrackScrollPane;
+    }
+
     public void updatePanelDimensions() {
         Insets insets = applicationHeaderPanel.getInsets();
         namePanelX = insets.left;
