@@ -377,12 +377,17 @@ public class ReferenceFrame {
 
 
     public void shiftOriginPixels(int delta) {
-
         double shiftBP = delta * getScale();
         setOrigin(shiftBP + origin);
         eventBus.post(ViewChange.LocusChangeResult(chrName, origin, getEnd(), false));
     }
 
+    public void shiftOriginPixelsPanning(int delta) {
+        double shiftBP = delta * getScale();
+        setOrigin(shiftBP + origin);
+        eventBus.post(ViewChange.LocusChangeResultPanning(chrName, origin, getEnd(), false));
+    }
+
     public void centerOnLocation(String chr, double chrLocation) {
         if (!chrName.equals(chr)) {
             setChromosomeName(chr);
@@ -757,11 +762,7 @@ public class ReferenceFrame {
     }
 
     public void setExpandedInsertion(InsertionMarker im) {
-        InsertionMarker previousInsertion = this.expandedInsertion;
         this.expandedInsertion = im;
-        if (im == null && previousInsertion != null) {
-            this.centerOnLocation(previousInsertion.position);
-        }
     }
 
     public InsertionMarker getExpandedInsertion() {
