@@ -34,7 +34,7 @@
 package org.broad.igv.ui.panel;
 
 
-import org.apache.log4j.Logger;
+import org.broad.igv.logging.*;
 import org.broad.igv.prefs.Constants;
 import org.broad.igv.prefs.PreferencesManager;
 import org.broad.igv.track.Track;
@@ -46,11 +46,11 @@ import org.broad.igv.ui.dnd.AbstractGhostDropManager;
 import org.broad.igv.ui.dnd.GhostDropEvent;
 import org.broad.igv.ui.dnd.GhostDropListener;
 import org.broad.igv.ui.dnd.GhostGlassPane;
+import org.broad.igv.ui.util.IGVMouseInputAdapter;
 import org.broad.igv.ui.util.UIUtilities;
 import org.jdesktop.layout.GroupLayout;
 
 import javax.swing.*;
-import javax.swing.event.MouseInputAdapter;
 import java.awt.*;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
@@ -66,7 +66,7 @@ import java.util.List;
  */
 public class TrackNamePanel extends TrackPanelComponent implements Paintable {
 
-    private static Logger log = Logger.getLogger(TrackNamePanel.class);
+    private static Logger log = LogManager.getLogger(TrackNamePanel.class);
 
 
     List<GroupExtent> groupExtents = new ArrayList();
@@ -75,7 +75,6 @@ public class TrackNamePanel extends TrackPanelComponent implements Paintable {
     boolean showGroupNames = true;
     boolean showSampleNamesWhenGrouped = false;
 
-
     public TrackNamePanel(TrackPanel trackPanel) {
         super(trackPanel);
         init();
@@ -95,38 +94,46 @@ public class TrackNamePanel extends TrackPanelComponent implements Paintable {
 
         super.paintComponent(g);
 
-        if (PreferencesManager.getPreferences().getAsBoolean(Constants.ENABLE_ANTIALISING)) {
+        if (PreferencesManager.getPreferences().getAntiAliasing()) {
             ((Graphics2D) g).setRenderingHint(RenderingHints.KEY_TEXT_ANTIALIASING, RenderingHints.VALUE_TEXT_ANTIALIAS_ON);
         }
 
-
         removeMousableRegions();
         Rectangle visibleRect = getVisibleRect();
-        paintImpl(g, visibleRect);
+        paintImpl(g, visibleRect, false);
     }
 
 
-    public void paintOffscreen(Graphics2D g, Rectangle rect) {
-        g.setColor(Color.white);
-        g.fill(rect);
-        paintImpl(g, rect);
+    public void paintOffscreen(Graphics2D g, Rectangle rect, boolean batch) {
 
-        Color c = g.getColor();
-        g.setColor(Color.darkGray);
-        g.drawRect(rect.x, rect.y, rect.width, rect.height);
-        g.setColor(c);            //super.paintBorder(g);
-        //super.paintBorder(g);
+        Graphics borderGraphics = g.create();
+        borderGraphics.setColor(Color.lightGray);
+
+        g.setRenderingHint(RenderingHints.KEY_TEXT_ANTIALIASING, RenderingHints.VALUE_TEXT_ANTIALIAS_ON);
+        Graphics2D bg = (Graphics2D) g.create();
+        paintImpl(g, rect, true);
+
+        borderGraphics.drawRect(rect.x, rect.y, rect.width-1, rect.height-1);
+        borderGraphics.dispose();
+    }
+
+    @Override
+    public int getSnapshotHeight(boolean batch) {
+        return getHeight();
     }
 
 
-    private void paintImpl(Graphics g, Rectangle visibleRect) {
+    private void paintImpl(Graphics g, Rectangle visibleRect, boolean snapshot) {
 
         // Get available tracks
         Collection<TrackGroup> groups = getGroups();
         boolean isGrouped = groups.size() > 1;
 
+        Graphics2D fontGraphics = (Graphics2D) g.create();
+        fontGraphics.setColor(Color.BLACK);
 
         if (!groups.isEmpty()) {
+
             final Graphics2D graphics2D = (Graphics2D) g;
             graphics2D.setColor(Color.BLACK);
 
@@ -162,13 +169,13 @@ public class TrackNamePanel extends TrackPanelComponent implements Paintable {
                     int h = group.getHeight();
                     Rectangle groupRect = new Rectangle(visibleRect.x, regionY, visibleRect.width, h);
                     Rectangle displayableRect = getDisplayableRect(groupRect, visibleRect);
-                    regionY = printTrackNames(group, displayableRect, visibleRect, graphics2D, 0, regionY);
+                    regionY = printTrackNames(group, displayableRect, visibleRect, fontGraphics, 0, regionY, snapshot);
 
                     if (isGrouped) {
                         groupExtents.add(new GroupExtent(group, groupRect.y, groupRect.y + groupRect.height));
                         if (showGroupNames) {
                             //Rectangle displayableRect = getDisplayableRect(groupRect, visibleRect);
-                            group.renderName(graphics2D, displayableRect, group == selectedGroup);
+                            group.renderName(fontGraphics, displayableRect);
                         }
                     }
 
@@ -181,6 +188,8 @@ public class TrackNamePanel extends TrackPanelComponent implements Paintable {
             graphics2D.dispose();
             greyGraphics.dispose();
         }
+
+        fontGraphics.dispose();
     }
 
     private Rectangle getDisplayableRect(Rectangle trackRectangle, Rectangle visibleRect) {
@@ -198,8 +207,7 @@ public class TrackNamePanel extends TrackPanelComponent implements Paintable {
     }
 
     private int printTrackNames(TrackGroup group, Rectangle visibleRect, Rectangle clipRect,
-                                Graphics2D graphics2D, int regionX, int regionY) {
-
+                                Graphics2D graphics2D, int regionX, int regionY, boolean snapshot) {
 
         List<Track> tmp = new ArrayList(group.getVisibleTracks());
         final Color backgroundColor = PreferencesManager.getPreferences().getAsColor(Constants.BACKGROUND_COLOR);
@@ -223,15 +231,13 @@ public class TrackNamePanel extends TrackPanelComponent implements Paintable {
                     if (!isGrouped() || showSampleNamesWhenGrouped) {
                         Rectangle rect = new Rectangle(regionX, regionY, width, height);
                         //Graphics2D g2D = graphics; //(Graphics2D) graphics.create();
-                        if (track.isSelected()) {
+                        if (!snapshot && track.isSelected()) {
                             graphics2D.setBackground(Color.LIGHT_GRAY);
-                            graphics2D.clearRect(rect.x, rect.y, rect.width, rect.height);
                         } else {
                             graphics2D.setBackground(backgroundColor);
                         }
-                        Graphics2D trackGraphics = (Graphics2D) graphics2D.create();
-                        track.renderName(trackGraphics, rect, visibleRect);
-                        trackGraphics.dispose();
+                        graphics2D.clearRect(rect.x, rect.y, rect.width, rect.height);
+                        track.renderName(graphics2D, rect, visibleRect);
                     }
 
                 }
@@ -244,7 +250,7 @@ public class TrackNamePanel extends TrackPanelComponent implements Paintable {
 
     private void init() {
 
-        setBorder(javax.swing.BorderFactory.createLineBorder(Color.black));
+    //    setBorder(javax.swing.BorderFactory.createLineBorder(Color.black));
         setBackground(new java.awt.Color(255, 255, 255));
         GroupLayout dataTrackNamePanelLayout = new org.jdesktop.layout.GroupLayout(this);
         setLayout(dataTrackNamePanelLayout);
@@ -359,7 +365,7 @@ public class TrackNamePanel extends TrackPanelComponent implements Paintable {
      * Mouse adapter for the track name panel.  Supports multiple selection,
      * popup menu, and drag & drop within or between name panels.
      */
-    class NamePanelMouseAdapter extends MouseInputAdapter {
+    class NamePanelMouseAdapter extends IGVMouseInputAdapter {
 
         boolean isDragging = false;
         List<Track> dragTracks = new ArrayList();
@@ -370,6 +376,7 @@ public class TrackNamePanel extends TrackPanelComponent implements Paintable {
          * Mouse down.  Track selection logic goes here.
          */
         public void mousePressed(MouseEvent e) {
+            super.mousePressed(e);
 
             dragStart = e.getPoint();
 
@@ -428,15 +435,13 @@ public class TrackNamePanel extends TrackPanelComponent implements Paintable {
 
         }
 
+        @Override
         public void mouseReleased(MouseEvent e) {
 
-            if (log.isTraceEnabled()) {
-                log.trace("Enter mouseReleased");
-            }
+            super.mouseReleased(e);
 
             if (isDragging) {
 
-
                 Component c = e.getComponent();
 
                 IGV.getInstance().endDnD();
@@ -484,7 +489,7 @@ public class TrackNamePanel extends TrackPanelComponent implements Paintable {
 
         }
 
-
+        @Override
         public void mouseDragged(MouseEvent e) {
 
             Component c = e.getComponent();
@@ -550,14 +555,13 @@ public class TrackNamePanel extends TrackPanelComponent implements Paintable {
             setToolTipText(getTooltipTextForLocation(x, y));
         }
 
-
         /**
-         * Mouse was clicked.  Delegateaction to the track(s) clicked on. .
+         * Mouse was clicked.  Delegate action to the track(s) clicked on. .
          *
          * @param e
          */
         @Override
-        public void mouseClicked(final MouseEvent e) {
+        public void igvMouseClicked(final MouseEvent e) {
             for (MouseableRegion mouseRegion : mouseRegions) {
                 if (mouseRegion.containsPoint(e.getX(), e.getY())) {
                     for (Track t : mouseRegion.getTracks()) {
