@@ -218,28 +218,6 @@ public class FileUtils {
     }
 
 
-    /**
-     * Test to see if the first non-comment line (first line not starting with #) is tab-delimited with the
-     * given number of minimum columns.  Limit the test to the first 1,000 lines.
-     */
-    public static boolean isTabDelimited(BufferedReader reader, int minColumnCount) throws IOException {
-
-        int nLinesTested = 0;
-        String nextLine;
-        while ((nextLine = reader.readLine()) != null && nLinesTested < 1000) {
-            if (nextLine.startsWith("#")) {
-                continue;
-            }
-            nLinesTested++;
-            String[] tokens = nextLine.split("\t");
-            if (tokens.length >= minColumnCount) {
-                return true;
-            }
-        }
-        return false;
-
-    }
-
     /**
      * Return the first line not starting with commentChar
      *
@@ -386,9 +364,11 @@ public class FileUtils {
      * @return
      */
     public static String getAbsolutePath(String inputPath, String referencePath) {
+
         if (isRemote(inputPath) || referencePath == null) {
             return inputPath;
         }
+
         File inFile = new File(inputPath);
         if (inFile.isAbsolute()) {
             return inFile.getAbsolutePath();
