@@ -261,7 +261,7 @@ public class IGVSeekableBufferedStreamTest extends AbstractHeadlessTest{
         assertEquals(length, bytesRead);
 
         byte[] buffer2 = new byte[length];
-        SeekableStream bufferedStream = new IGVSeekableBufferedStream(new SeekableHTTPStream(HttpUtils.createURL(BAM_URL_STRING)));
+        SeekableStream bufferedStream = new IGVSeekableBufferedStream(new IGVSeekableHTTPStream(HttpUtils.createURL(BAM_URL_STRING)));
         bufferedStream.seek(startPosition);
         bytesRead = bufferedStream.read(buffer2, 0, length);
         assertEquals(length, bytesRead);
@@ -286,7 +286,7 @@ public class IGVSeekableBufferedStreamTest extends AbstractHeadlessTest{
 
 
         byte[] buffer = new byte[length];
-        SeekableStream bufferedStream = new IGVSeekableBufferedStream(new SeekableHTTPStream(HttpUtils.createURL(BAM_URL_STRING)));
+        SeekableStream bufferedStream = new IGVSeekableBufferedStream(new IGVSeekableHTTPStream(HttpUtils.createURL(BAM_URL_STRING)));
         bufferedStream.seek(startPosition);
         int bytesRead = bufferedStream.read(buffer, 0, length);
         assertEquals(remainder, bytesRead);
